clear all
set more off
grstyle init
grstyle color background white

global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    use "$working_dir/derived_data/meta_analysis_data", clear

    * Aggregate horizon 2 and 3
    qui reg estimate_migrate estimate_selfempl if horizon==1
    local coef_horizon_1 = round(_b[estimate_selfempl], .001)

    qui reg estimate_migrate estimate_selfempl if horizon==2 | horizon==3
    local coef_horizon_2and3 = round(_b[estimate_selfempl], .001)

    twoway (scatter estimate_migrate estimate_selfempl if horizon==1, mc(gs8)) ///
        (scatter estimate_migrate estimate_selfempl if horizon>1, ms(T) mc(gs8)) ///
        (lfit estimate_migrate estimate_selfempl if horizon==1, color(black) range(-.15 .55)) ///
        (lfit estimate_migrate estimate_selfempl if horizon>1, color(black) lpattern(dash) range(-.15 .55)) ///
        (rcap ci_lo_migrate ci_hi_migrate estimate_selfempl, lc(gs8)) ///
        (rcap ci_lo_selfempl ci_hi_selfempl estimate_migrate, horizontal lc(gs8)), ///
        legend(size(small) order(1 "Up to 2 years" 3 "Up to 2 years, fitted line (coef: `coef_horizon_1')" ///
            2 "More than 2 years" 4 "More than 2 years, fitted line (coef: `coef_horizon_2and3')")) ///
        ytitle("Program effect on migration") xtitle("Program effect on self-employment")

    graph export "$working_dir/output/causal/rcts_coefficients.png", replace


    * Migration vs lag self-employment
    egen horizon_group=group(horizon ind)
    egen rct_nbr = group(rct) 

    foreach var in estimate_migrate ci_lo_migrate ci_hi_migrate horizon control_mean_migrate {
        bys rct_nbr (horizon_group): gen lead_`var' = `var'[_n+1]
    }
    
    qui reg lead_estimate_migrate estimate_selfempl
    local coef = round(_b[estimate_selfempl], .001)
    
    twoway (scatter lead_estimate_migrate estimate_selfempl if lead_horizon==1, mc(gs8)) ///
        (scatter lead_estimate_migrate estimate_selfempl if lead_horizon>1, ms(T) mc(gs8)) ///
        (lfit lead_estimate_migrate estimate_selfempl, color(black) range(-.15 .5)) ///
        (rcap lead_ci_lo_migrate lead_ci_hi_migrate estimate_selfempl, lc(gs8)) ///
        (rcap ci_lo_selfempl ci_hi_selfempl lead_estimate_migrate, horizontal lc(gs8)), ///
        legend(size(small) order(1 "Up to 2 years" 2 "More than 2 years" 3 "Fitted line (coef: `coef')")) ///
        ytitle("Program effect on migration") xtitle("Program effect on self-employment in previous period")

    graph export "$working_dir/output/causal/rcts_coefficients_lagSelfEmpl.png", replace


    * Forest plot for long-term effects
    keep if horizon>1

    gen endline = ""
    replace endline = "4-year" if rct=="Blattman YOP" & horizon==2
    replace endline = "9-year" if rct=="Blattman YOP" & horizon==3
    replace endline = "3-year" if rct=="McKenzie Ghana" & horizon==2
    replace endline = "6-year" if rct=="McKenzie SriLanka Business" & horizon==3
    replace endline = "5-year" if rct=="McKenzie SriLanka Grants" & horizon==2
    replace endline = "10-year" if rct=="McKenzie SriLanka Grants" & horizon==3
    replace endline = "3-year" if rct=="McKenzie YouWin" & horizon==2 & ind==1
    replace endline = "5-year" if rct=="McKenzie YouWin" & horizon==2 & ind==2

    replace rct="Uganda YOP" if rct=="Blattman YOP"
    replace rct="Ghana microenterprises" if rct=="McKenzie Ghana"
    replace rct="Sri Lanka SIYB" if rct=="McKenzie SriLanka Business"
    replace rct="Sri Lanka SLMS" if rct=="McKenzie SriLanka Grants"
    replace rct="Nigeria YouWin!" if rct=="McKenzie YouWin"

    metan estimate_migrate se_migrate, random label(namevar=rct, yearvar=endline) textsize(200) dp(3)

    graph export "$working_dir/output/causal/meta_analysis_forest_logterm.png", replace
end

* Execute
main
