clear all
set more off

global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"
adopath + "$working_dir/lib/"

program main
    use "$working_dir/derived_data/meta_analysis_data", clear

    mat table = J(15,8,.)
    mat table_df = J(15,8,.)

    gen more_2_years = horizon==2 | horizon==3

    *** Specification 0 ***
    reg estimate_migrate more_2_years

    foreach outcome in migrate selfempl {
        sum estimate_`outcome' if e(sample)
        local mean_itt_`outcome' = `r(mean)'
    }
    
    columns_specif0

    foreach stub in "" "_df" {
        mat table`stub'[1,1] = column_p1`stub'
        mat table`stub'[7,1] = column_p2`stub'
        mat table`stub'[13,1] = (`mean_itt_migrate' \ `mean_itt_selfempl' \ e(N))
    }

    test _b[_cons] + _b[more_2_years]==0

    * Fixed effects meta regression
    metareg estimate_migrate more_2_years, wsse(se_migrate) mm

    metan estimate_migrate se_migrate if e(sample), random
    local mean_itt_migrate_fe = `r(ES)'

    columns_specif0

    foreach stub in "" "_df" {
        mat table`stub'[1,5] = column_p1`stub'
        mat table`stub'[7,5] = column_p2`stub'
        mat table`stub'[13,5] = (`mean_itt_migrate_fe' \ `mean_itt_selfempl' \ e(N))
    }


    
    *** Specification 1 ***
    reg estimate_migrate estimate_selfempl more_2_years control_mean_migrate
    
    foreach outcome in migrate selfempl {
        sum estimate_`outcome' if e(sample)
        local mean_itt_`outcome' = `r(mean)'
    }
    
    columns_specif1
    
    foreach stub in "" "_df" {
        mat table`stub'[1,2] = column`stub'
        mat table`stub'[13,2] = (`mean_itt_migrate' \ `mean_itt_selfempl' \ e(N))
    }

    * Fixed effects meta regression
    metareg estimate_migrate estimate_selfempl more_2_years control_mean_migrate, wsse(se_migrate) mm

    metan estimate_migrate se_migrate if e(sample), random
    local mean_itt_migrate_fe = `r(ES)'

    columns_specif1
    
    foreach stub in "" "_df" {
        mat table`stub'[1,6] = column`stub'
        mat table`stub'[13,6] = (`mean_itt_migrate_fe' \ `mean_itt_selfempl' \ e(N))
    }



    *** Specification 2 ***
    gen estimate_selfempl_2year = estimate_selfempl*more_2_years

    reg estimate_migrate estimate_selfempl more_2_years estimate_selfempl_2year control_mean_migrate
    
    foreach outcome in migrate selfempl {
        sum estimate_`outcome' if e(sample)
        local mean_itt_`outcome' = `r(mean)'
    }

    columns_specif2_3

    foreach stub in "" "_df" {
        mat table`stub'[1,3] = column`stub'
        mat table`stub'[13,3] = (`mean_itt_migrate' \ `mean_itt_selfempl' \ e(N))
    }

    * Fixed effects meta regression
    metareg estimate_migrate estimate_selfempl more_2_years estimate_selfempl_2year ///
        control_mean_migrate, wsse(se_migrate) mm

    metan estimate_migrate se_migrate if e(sample), random
    local mean_itt_migrate_fe = `r(ES)'

    columns_specif2_3
    
    foreach stub in "" "_df" {
        mat table`stub'[1,7] = column`stub'
        mat table`stub'[13,7] = (`mean_itt_migrate_fe' \ `mean_itt_selfempl' \ e(N))
    }



    *** Specification 4 ***
    egen horizon_group=group(horizon ind)
    egen rct_nbr = group(rct) 

    foreach var in estimate_migrate se_migrate {
        bys rct_nbr (horizon_group): gen lead_`var' = `var'[_n+1]
    }

    reg lead_estimate_migrate estimate_selfempl
    
    foreach outcome in migrate selfempl {
        sum estimate_`outcome' if e(sample)
        local mean_itt_`outcome' = `r(mean)'
    }

    columns_specif4
    
    foreach stub in "" "_df" {
        mat table`stub'[1,4] = column_p1`stub'
        mat table`stub'[11,4] = column_p2`stub'
        mat table`stub'[13,4] = (`mean_itt_migrate' \ `mean_itt_selfempl' \ e(N))
    }

    * Fixed effects meta regression
    metareg lead_estimate_migrate estimate_selfempl, wsse(lead_se_migrate) mm

    metan lead_estimate_migrate lead_se_migrate if e(sample), random
    local mean_itt_migrate_fe = `r(ES)'

    columns_specif4
    
    foreach stub in "" "_df" {
        mat table`stub'[1,8] = column_p1`stub'
        mat table`stub'[11,8] = column_p2`stub'
        mat table`stub'[13,8] = (`mean_itt_migrate_fe' \ `mean_itt_selfempl' \ e(N))
    }


    * Build table
    signifstars, mat_name(table)
    mat table_stars = r(stars)

    local rtitles = `" "Intercept" \ "" \ "ITT self-employment" \ "" \ "Migration control mean" \ "" \ "More than 2 years" \ "" "' + ///
        `" \ "More than 2 years x ITT self-empl" \ "" \ "Lag ITT self-empl" \ "" \ "Mean ITT migration" \ "Mean ITT self-employment" \ "Sample size" "'

    frmttable using "$working_dir/output/causal/meta_regression_table", ///
        statmat(table) sdec(3) annotate(table_stars) asymbol(*,**,***) ///
        tex replace fragment rtitles(`rtitles')
end

program columns_specif0
    mat column_p1 = (_b[_cons] \ _se[_cons])
    mat column_p1_df = (`e(df_r)' \ .)
        
    mat column_p2 = (_b[more_2_years] \ _se[more_2_years])
    mat column_p2_df = (`e(df_r)' \ .)
end

program columns_specif1
    mat column = (_b[_cons] \ _se[_cons] \ ///
        _b[estimate_selfempl] \ _se[estimate_selfempl] \ ///
        _b[control_mean_migrate] \ _se[control_mean_migrate] \ ///
        _b[more_2_years] \ _se[more_2_years])
    mat column_df = (`e(df_r)' \ . \ `e(df_r)' \ . \ `e(df_r)' \ . \ `e(df_r)' \ .)
end

program columns_specif2_3
    mat column = (_b[_cons] \ _se[_cons] \ ///
        _b[estimate_selfempl] \ _se[estimate_selfempl] \ ///
        _b[control_mean_migrate] \ _se[control_mean_migrate] \ ///
        _b[more_2_years] \ _se[more_2_years] \ ///
        _b[estimate_selfempl_2year] \ _se[estimate_selfempl_2year])
    mat column_df = (`e(df_r)' \ . \ `e(df_r)' \ . \ `e(df_r)' \ . \ `e(df_r)' \ . \ `e(df_r)' \ .)
end

program columns_specif4
    mat column_p1 = (_b[_cons] \ _se[_cons])
    mat column_p1_df = (`e(df_r)' \ .)
        
    mat column_p2 = (_b[estimate_selfempl] \ _se[estimate_selfempl])
    mat column_p2_df = (`e(df_r)' \ .)
end

* Execute
main
