clear all
set more off

global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"
adopath + "$working_dir/lib/"

program main
    foreach stub in "" "_df" {
        cap: mat drop selfempl_tab`stub' any_employment_tab`stub'
    }

    define_globals
    
    * Effects for each program
    file open estimates_file using "$working_dir/output/causal/estimates.txt", write replace
    file write estimates_file "rct" _tab "horizon" _tab "ind" _tab "variable" _tab "estimate" ///
        _tab "se" _tab "N" _tab "control_mean" _n

    yop_extensive_margin_regs
    wings_regs
    slms_regs
    siyb_regs
    ghana_regs
    youwin_regs

    file close estimates_file

    build_table

    yop_intensive_margin
end

program define_globals
    * Use same controls as in Blattman et al (2014)
    gl controls_yop = "D_1-D_13 " + /// 
        "age age_2 age_3 urban ind_found_b risk_aversion " + ///
        "education literate voc_training numeracy_numcorrect_m adl " + ///
        "wealthindex savings_6mo_p99 cash4w_p99 loan_100k loan_1mil " + ///
        "lowskill7da_zero lowbus7da_zero skilledtrade7da_zero highskill7da_zero acto7da_zero " + ///
        "aghours7da_zero chores7da_zero zero_hours nonag_dummy emplvoc inschool " + ///
        "admin_cost_us groupsize_est_e grantsize_pp_US_est3 group_existed group_age " + ///
        "ingroup_hetero ingroup_dynamic grp_leader grp_chair avgdisteduc"

    // OUTCOMES
    gl outcomes_intensive_yop = "totalhrs7da_zero_e aghours7da_zero_e nonaghours7da_zero_e lowskill7da_zero_e " + ///
        "highskill7da_zero_e skilledtrade7da_zero_e zero_hours_e nonag_dummy_e trade_dummy_e fulltimeskill_e"

    * Use same controls as in Blattman et al (2016)
    gl controls_wings = "age_bas female hhsize_bas partner_bas onlyearner_bas biochildren_bas nonacholi_bas " + ///
        "stillenrolled_bas attainment_dup_p1e writingskills_bas speakengl_bas trainlength_bas stddigitrecall " + ///
        "pettybiz_dum_bas dugo1_hrs7d_p99_bas duge1_hrs7d_p99_bas casual_hrs7d_p99_bas  brew_hrs7d_p99_bas " + ///
        "buy_hrs7d_p99_bas others_hrs7d_p99_bas chores_hrs7d_p99_bas zero_employment_bas " + ///
        "wealthindex_all_bas cashtotal4w_basp99_1000 otherhh_earnings_bas savingsgroup_bas savings_basp99_1000 " + ///
        "currloans_basp99_1000 creditaccess15_bas creditaccess100_bas " + ///
        "hhsupport_z_bas commparticipation_z_bas neighborsupport_z_bas groupsin_bas comm_maltreat_bas " + ///
        "physemo_abuse_z_bas decision_making_z_bas womens_rights_z_bas relatedchief_bas " + ///
        "healthindex_bas hiv_bas APAI_R_z_bas " + ///
        "war_exper_bas_z recruited_bas carriedgun_bas forciblymarried_bas borechild_bas " + ///
        "risk_aversion_bas patience_zscore " + ///
        "vilpopulation c_np_educ2 siteid_sample_p1 remoteness pricelevel rentland_sq camp ngo_total " + ///
        "c_vending_p99 c_kiosk_p99 c_shops_p99 c_tailoring_p99 c_hotel_p99 c_othercommarket distancetocapital district1 " + /// 
        "D_T_bar_4_b50 D_T_4_b50"
end

program yop_extensive_margin_regs
    use "$working_dir/derived_data/master_panel_causal", clear
    keep if rct=="YOP"

    foreach e in e1 e2 e3 {
        
        * Set survey design and horizon
        if "`e'" == "e1" {
            local s_weight w_sampling_e
            local horizon 1
        }
        else if "`e'" == "e2" {
            local s_weight w_sampling_e
            local horizon 2
        }
        else if "`e'" == "e3" {
            local s_weight weight
            local horizon 3
        }
        svyset [pw=`s_weight'], strata(district) psu(groupid)

        * ITT regressions
        foreach y in selfempl any_employment migrate {
            qui sum `y' [iw=`s_weight'] if `e'==1 & assigned==0
            local control_mean = `r(mean)'

            qui svy: reg `y' assigned female $controls_yop if `e' == 1
            
            mat `y' = (`e(N)', `control_mean', _b[assigned] \ ., ., _se[assigned])
            mat `y'_df = (., ., `e(df_r)' \ ., ., .)

            file write estimates_file "Blattman YOP" _tab "`horizon'" _tab "1" _tab "`y'" _tab ///
                (_b[assigned]) _tab (_se[assigned]) _tab (e(N)) _tab "`control_mean'" _n
        }

        * IV regressions
        foreach endog in selfempl any_employment {
            qui svy: ivreg migrate (`endog' = assigned) female $controls_yop if `e' == 1
            
            mat `endog'_iv = (_b[`endog'] \ _se[`endog'])
            mat `endog'_iv_df = (`e(df_r)' \ .)

            foreach stub in "" "_df" {
                mat `endog'_tab`stub' = (nullmat(`endog'_tab`stub') \ `endog'`stub', migrate`stub', `endog'_iv`stub')
            }
        }
    }
end

program wings_regs
    use "$working_dir/derived_data/master_panel_causal", clear
    keep if rct=="WINGS"

    * ITT regressions
    foreach y in selfempl any_employment migrate {
        qui sum `y' if sample_p1 == 1 & found_p1e == 1 & assigned_p1 == 0
        local control_mean = `r(mean)'

        qui reg `y' assigned_p1 assigned_p1_gd $controls_wings if ///
            sample_p1==1 & found_p1e == 1, cluster(siteid)
        
        qui lincom assigned_p1 + assigned_p1_gd

        mat `y' = (`e(N)', `control_mean', `r(estimate)' \ ., ., `r(se)')
        mat `y'_df = (., ., `r(df)' \ ., ., .)

        file write estimates_file "Blattman WINGS" _tab "1" _tab "1" _tab "`y'" _tab ///
            (r(estimate)) _tab (r(se)) _tab (e(N)) _tab "`control_mean'" _n
    }

    * IV regressions
    foreach endog in selfempl any_employment {
        qui ivreg migrate (`endog' = assigned_p1 assigned_p1_gd) $controls_wings ///
            if sample_p1==1 & found_p1e == 1, cluster(siteid)

        mat `endog'_iv = (_b[`endog'] \ _se[`endog'])
        mat `endog'_iv_df = (`e(df_r)' \ .)

        foreach stub in "" "_df" {
            mat `endog'_tab`stub' = (nullmat(`endog'_tab`stub') \ `endog'`stub', migrate`stub', `endog'_iv`stub')
        }
    }
end

program slms_regs
    use "$working_dir/derived_data/master_panel_causal", clear
    keep if rct=="SLMS"

    forvalues endline=1/2 {
        
        if `endline'==1 local horizon 2
        else if `endline'==2 local horizon 3

        * ITT regressions
        foreach y in selfempl any_employment migrate {
            qui reg `y' mamount if male==1 & endline==`endline', robust
            
            qui sum `y' if male==1 & mamount<1 & e(sample)
            local control_mean = `r(mean)'

            mat `y' = (`e(N)', `control_mean', _b[mamount] \ ., ., _se[mamount])
            mat `y'_df = (., ., `e(df_r)' \ ., ., .)

            file write estimates_file "McKenzie SriLanka Grants" _tab "`horizon'" _tab "1" _tab "`y'" _tab ///
                (_b[mamount]) _tab (_se[mamount]) _tab (e(N)) _tab "`control_mean'" _n
        }

        * IV regressions
        foreach endog in selfempl any_employment {
            qui ivreg migrate (`endog' = mamount) if male==1 & endline==`endline', robust
            
            mat `endog'_iv = (_b[`endog'] \ _se[`endog'])
            mat `endog'_iv_df = (`e(df_r)' \ .)

            foreach stub in "" "_df" {
                mat `endog'_tab`stub' = (nullmat(`endog'_tab`stub') \ `endog'`stub', migrate`stub', `endog'_iv`stub')
            }
        }
    }
end

program siyb_regs
    use "$working_dir/derived_data/master_panel_causal", clear
    keep if rct=="SIYB"

    foreach round1 of numlist 2 4 {
        local round2 = `round1' + 1

        if `round1'==2 local ind 1
        if `round1'==4 local ind 2

        foreach y in selfempl any_employment migrate {
            * Compound treatment
            qui areg `y' treated i.round if (round==`round1' | round==`round2'), absorb(newstrata) cluster(sheno)

            qui sum `y' if evercash==0 & evertrain==0 & (round==`round1' | round==`round2') & e(sample)
            local control_mean = `r(mean)'

            mat `y' = (`e(N)', `control_mean', _b[treated] \ ., ., _se[treated])
            mat `y'_df = (., ., `e(df_r)' \ ., ., .)

            file write estimates_file "McKenzie SriLanka Business" _tab "1" _tab "`ind'" _tab "`y'" _tab ///
                (_b[treated]) _tab (_se[treated]) _tab (e(N)) _tab "`control_mean'" _n
        }

        foreach endog in selfempl any_employment {
            qui ivreghdfe migrate i.round (`endog' = treated) if (round==`round1' | round==`round2'), absorb(newstrata) cluster(sheno)
            
            mat `endog'_iv = (_b[`endog'] \ _se[`endog'])
            mat `endog'_iv_df = (`e(df_r)' \ .)

            foreach stub in "" "_df" {
                mat `endog'_tab`stub' = (nullmat(`endog'_tab`stub') \ `endog'`stub', migrate`stub', `endog'_iv`stub')
            }
        }
    }

    * Round 6
    foreach y in selfempl any_employment migrate {
        qui areg `y' treated if round==6, absorb(newstrata) robust

        qui sum `y' if evercash==0 & evertrain==0 & round==6 & e(sample)
        local control_mean = `r(mean)'

        mat `y' = (`e(N)', `control_mean', _b[treated] \ ., ., _se[treated])
        mat `y'_df = (., ., `e(df_r)' \ ., ., .)

        file write estimates_file "McKenzie SriLanka Business" _tab "3" _tab "1" _tab "`y'" _tab ///
            (_b[treated]) _tab (_se[treated]) _tab (e(N)) _tab "`control_mean'" _n
    }

    foreach endog in selfempl any_employment {
        qui ivreghdfe migrate (`endog' = treated) if round==6, absorb(newstrata) robust
        
        mat `endog'_iv = (_b[`endog'] \ _se[`endog'])
        mat `endog'_iv_df = (`e(df_r)' \ .)

        foreach stub in "" "_df" {
            mat `endog'_tab`stub' = (nullmat(`endog'_tab`stub') \ `endog'`stub', migrate`stub', `endog'_iv`stub')
        }
    }
end

program ghana_regs
    use "$working_dir/derived_data/master_panel_causal", clear
    keep if rct=="Ghana"

    * ITT regressions short-term
    * (Some observations have missing survival status)
    foreach y in selfempl any_employment migrate {
        qui areg `y' treatment wave2-wave6 if female==0 & wave!=7, absorb(groupnum) cluster(sheno)

        qui sum `y' if treatment==0 & female==0 & wave!=7 & e(sample)
        local control_mean = `r(mean)'

        mat `y' = (`e(N)', `control_mean', _b[treatment] \ ., ., _se[treatment])
        mat `y'_df = (., ., `e(df_r)' \ ., ., .)

        file write estimates_file "McKenzie Ghana" _tab "1" _tab "1" _tab "`y'" _tab ///
            (_b[treatment]) _tab (_se[treatment]) _tab (e(N)) _tab "`control_mean'" _n
    }
    
    * ITT regressions long-term
    foreach y in selfempl any_employment migrate {
        qui areg `y' treatment if wave==7 & female==0, absorb(groupnum) cluster(sheno)

        qui sum `y' if treatment==0 & wave==7 & female==0 & e(sample)
        local control_mean = `r(mean)'

        mat `y'_lt = (`e(N)', `control_mean', _b[treatment] \ ., ., _se[treatment])
        mat `y'_lt_df = (., ., `e(df_r)' \ ., ., .)

        file write estimates_file "McKenzie Ghana" _tab "2" _tab "1" _tab "`y'" _tab ///
            (_b[treatment]) _tab (_se[treatment]) _tab (e(N)) _tab "`control_mean'" _n
    }

    * IV regressions
    foreach endog in selfempl any_employment { 
        qui ivreghdfe migrate wave2-wave6 (`endog' = treatment) if female==0 & wave!=7, absorb(groupnum) cluster(sheno)
        
        mat `endog'_iv = (_b[`endog'] \ _se[`endog'])
        mat `endog'_iv_df = (`e(df_r)' \ .)

        qui ivreghdfe migrate (`endog' = treatment) if wave==7 & female==0, absorb(groupnum)
        
        mat `endog'_lt_iv = (_b[`endog'] \ _se[`endog'])
        mat `endog'_lt_iv_df = (`e(df_r)' \ .)
        
        foreach stub in "" "_df" {
            mat `endog'_tab`stub' = (nullmat(`endog'_tab`stub') \ `endog'`stub', migrate`stub', `endog'_iv`stub' \ ///
                `endog'_lt`stub', migrate_lt`stub', `endog'_lt_iv`stub')
        }
    }
end

program youwin_regs
    use "$working_dir/derived_data/master_panel_causal", clear
    keep if rct=="YouWin"

    foreach endline in s t f {

        if "`endline'"=="s" {
            local horizon 1
            local ind 1
        }
        else if "`endline'"=="t" {
            local horizon 2
            local ind 1
        }
        else if "`endline'"=="f" {
            local horizon 2
            local ind 2
        }

        * ITT regressions
        foreach var in migrate selfempl any_employment {
            qui areg `endline'_`var' assigntreat if experimentalsample==1, a(strata) robust
        
            qui sum `endline'_`var' if e(sample)==1 & assigntreat==0
            local control_mean = `r(mean)'

            mat `endline'_`var' = (`e(N)', `control_mean', _b[assigntreat] \ ., ., _se[assigntreat])
            mat `endline'_`var'_df = (., ., `e(df_r)' \ ., ., .)

            file write estimates_file "McKenzie YouWin" _tab "`horizon'" _tab "`ind'" _tab "`var'" _tab ///
                (_b[assigntreat]) _tab (_se[assigntreat]) _tab (e(N)) _tab "`control_mean'" _n
        }

        * IV regressions
        foreach endog in selfempl any_employment {
            qui xi: ivreg2 `endline'_migrate (`endline'_`endog' = assigntreat) i.strata, robust

            mat `endline'_`endog'_iv = (_b[`endline'_`endog'] \ _se[`endline'_`endog'])
            mat `endline'_`endog'_iv_df = (`e(Fdf2)' \ .)

            foreach stub in "" "_df" {
                mat `endog'_tab`stub' = (nullmat(`endog'_tab`stub') \ `endline'_`endog'`stub', ///
                    `endline'_migrate`stub', `endline'_`endog'_iv`stub')
            }
        }
    }
end

program build_table 
    foreach endog in selfempl any_employment {
        signifstars, mat_name(`endog'_tab)
        mat `endog'_tab_stars = r(stars)

        local ctitles = `" "", "Sample size", "Control mean", "ITT", "Sample size", "Control mean", "ITT", "IV" "'
        local rtitles = `" "YOP (2-year)" \ "" \ "YOP (4-year)" \ "" \ "YOP (9-year)" \ "" \ "WINGS (16-month)" \ "" \ "' + ///
            `" "SLMS (5-year)" \ "" \ "SLMS (10-year)" \ "" \ "SIYB (8-month)" \ "" \ "SIYB (25-month)" \ "" \ "' + /// 
            `" "SIYB (6-year)" \ "" \ "Ghana (1-year)" \ "" \ "Ghana (3-year)" \ "" \ "YouWin! (2-year)" \ "" \ "' + ///
            `" "YouWin! (3-year)" \ "" \ "YouWin! (5-year)" \ "" "'
        
        frmttable using "$working_dir/output/causal/`endog'_tab", ///
            statmat(`endog'_tab) sdec(3) annotate(`endog'_tab_stars) asymbol(*,**,***) ///
            tex replace fragment ctitles(`ctitles') rtitles(`rtitles')
    }
end

program yop_intensive_margin
    use "$working_dir/derived_data/master_panel_causal", clear
    keep if rct=="YOP"

    foreach e in e1 e2 e3 {

        if "`e'" == "e1" | "`e'" == "e2" {
            local s_weight w_sampling_e
        }
        else if "`e'" == "e3" {
            local s_weight weight
        }
        svyset [pw=`s_weight'], strata(district) psu(groupid)

        qui sum migrate [iw=`s_weight'] if `e'==1 & assigned==0
        local control_mean = `r(mean)'

        qui svy: reg migrate assigned female $controls if `e' == 1
        
        mat migrate_`e' = (`e(N)', `control_mean', _b[assigned], . \ ., ., _se[assigned], .)
        mat migrate_`e'_df = (., ., `e(df_r)', . \ ., ., ., .)

        foreach y in $outcomes_intensive_yop {
            qui sum `y' [iw=`s_weight'] if `e'==1 & assigned==0
            local control_mean = `r(mean)'

            qui svy: reg `y' assigned female $controls_yop if `e' == 1
            
            mat `y'_`e' = (`e(N)', `control_mean', _b[assigned] \ ., ., _se[assigned])
            mat `y'_`e'_df = (., ., `e(df_r)' \ ., ., .)

            qui svy: ivreg migrate (`y' = assigned) female $controls_yop if `e' == 1
            
            mat `y'_iv_`e' = (_b[`y'] \ _se[`y'])
            mat `y'_iv_`e'_df = (`e(df_r)' \ .)
        }

        foreach stub in "" "_df" {
            mat int_`e'`stub' = (migrate_`e'`stub' \ (totalhrs7da_zero_e_`e'`stub', totalhrs7da_zero_e_iv_`e'`stub') \ (aghours7da_zero_e_`e'`stub', aghours7da_zero_e_iv_`e'`stub') \ ///
                (nonaghours7da_zero_e_`e'`stub', nonaghours7da_zero_e_iv_`e'`stub') \ (lowskill7da_zero_e_`e'`stub', lowskill7da_zero_e_iv_`e'`stub') \ ///
                (highskill7da_zero_e_`e'`stub', highskill7da_zero_e_iv_`e'`stub') \ (skilledtrade7da_zero_e_`e'`stub', skilledtrade7da_zero_e_iv_`e'`stub') \ (zero_hours_e_`e'`stub', zero_hours_e_iv_`e'`stub') \ ///
                (nonag_dummy_e_`e'`stub', nonag_dummy_e_iv_`e'`stub') \ (trade_dummy_e_`e'`stub', trade_dummy_e_iv_`e'`stub') \ (fulltimeskill_e_`e'`stub', fulltimeskill_e_iv_`e'`stub'))
        }
    }

    foreach stub in "" "_df" {
        mat specific_activities`stub' = (int_e1`stub', int_e2`stub', int_e3`stub')
    }

    signifstars, mat_name(specific_activities)
    mat specific_activities_stars = r(stars)

    local ctitles = `""", "Sample size", "Control mean", "ITT", "IV", "Sample size", "Control mean", "ITT", "IV", "' + ///
        `""Sample size", "Control mean", "ITT", "IV""'
    local rtitles = `""Migration" \ "" \ "Hours worked non chores" \ "" \ "Hours agricultural activities" \ "" \ "' + ///
        `""Hours non-agricultural act" \ "" \ "Hours low-skill labor" \ "" \ "Hours high-skill labor" \ "" \ "' + ///
        `""Hours skilled trades" \ "" \ "No employment hours past month" \ "" \ "Main occ non-agricultural" \ "" \ "' + ///
        `""Any skilled trade" \ "" \ "More 30 hours skilled trade" \ "" "'

    frmttable using "$working_dir/output/causal/yop_specific_activities", ///
        statmat(specific_activities) sdec(3) annotate(specific_activities_stars) asymbol(*,**,***) ///
        tex replace fragment ctitles(`ctitles') rtitles(`rtitles')
end

* Execute
main
