clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/RCTs/replication_data"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    local varlist "SHENO introduction_*"

    use `varlist' using "$raw_data_dir/McKenzie_Ghana/Location data/GhanaRound2Single.dta", clear
    gen wave = 2
    
    forvalues round=3/5 {
        append using "$raw_data_dir/McKenzie_Ghana/Location data/GhanaRound`round'Single.dta", keep(`varlist')
        replace wave = `round' if wave==.
    }
    forvalues round=6/7 {
        append using "$raw_data_dir/McKenzie_Ghana/Location data/GhanaRound`round'Introductions.dta", keep(`varlist')
        replace wave = `round' if wave==.
    }

    drop if SHENO=="."

    ****** Any work ******
    gen any_employment = 0
    replace any_employment = 1 if introduction_6=="Yes"
    replace any_employment = 1 if introduction_11=="Operating a different business"
    replace any_employment = 1 if introduction_11=="Wage worker"
    replace any_employment = 1 if strpos(introduction_11, "operating same line of business")>0
    replace any_employment = 1 if introduction_11=="SELLING  ALCOHOLIC DRINKS"

    ****** Business work ******
    gen selfempl = 0
    replace selfempl = 1 if introduction_6=="Yes"
    replace selfempl = 1 if introduction_11=="Operating a different business"

    ****** Migration ******
    * NOTE: Code migration = 1 if move out of Greater Accra Region

    replace introduction_5 = lower(introduction_5)

    gen migrate = 0
    replace migrate = 1 if strpos(introduction_5, "kasoe")>0 // Just West of Greater Accra Region
    replace migrate = 1 if strpos(introduction_5, "kasoa")>0
    replace migrate = 1 if strpos(introduction_5, "kasowa")>0

    replace migrate = 1 if strpos(introduction_5, "manhyia")>0 // Close to Kumasi
    replace migrate = 1 if strpos(introduction_5, "nsawam")>0 // North of Accra
    replace migrate = 1 if strpos(introduction_5, "alavanyo")> 0 // Town in Volta Region

    * Extended version of migration: every move counts
    gen ext_migrate = introduction_4=="No"
   
    foreach var in migrate ext_migrate {
        * Assume stays in same place after migrating
        bys SHENO (wave): gen `var'_t = sum(`var')
        replace `var' = 1 if `var'_t>=1 & `var'_t!=.

        * Deal with duplicates
        bys SHENO wave: egen max_`var'=max(`var')
        replace `var'=max_`var'
    }

    keep SHENO wave migrate ext_migrate selfempl any_employment
    destring SHENO, gen(sheno)

    foreach var in selfempl any_employment {
        bys sheno wave: egen max_`var' = max(`var')
        replace `var' = max_`var'
        drop max_`var'
    }
    duplicates drop

    save "$working_dir/temp/ghana", replace

    use "$raw_data_dir/McKenzie_Ghana/GHA_2008_MGFERE_v01_M_Stata8/ReplicationDataGhanaJDE.dta", clear
    append using "$raw_data_dir/McKenzie_Ghana/GHA_2008_MGFERE_v01_M_Stata8/r7tomerge.dta"

    tsset sheno wave
    foreach var in atreat cashtreat equiptreat atreatcash atreatequip female trimgroup wave2 wave3 wave4 wave5 wave6 groupnum highgroup mlowgroup {
        replace `var'=L.`var' if wave==7
        replace `var'=L2.`var' if wave==7 & `var'==.
    }

    merge 1:1 sheno wave using "$working_dir/temp/ghana", ///
        keep(1 3) assert(1 2 3)

    * Some respondents have additional information beyond survey
    foreach var in selfempl any_employment {
        replace `var' = stillownbusiness if (stillownbusiness!=. & `var'==.) | stillownbusiness==1
        replace `var' = surviver7 if (surviver7!=. & `var'==.) | surviver7==1
    }

    foreach var in migrate ext_migrate {
        bys SHENO (wave): gen `var'_t = sum(`var')
        replace `var' = 1 if `var'_t>=1 & `var'_t!=.
        replace `var' = 0 if `var'==.
    }

    drop atreatcashfemale atreatequipfemale atreatcashmale atreatequipmale wave2_female-wave6_female
    gen wave7 = wave==7
    replace male = 1 if male==. & female==0
    replace male = 0 if male==. & female==1

    gen atreatcashfemale=atreatcash*female
    gen atreatequipfemale=atreatequip*female
    gen atreatcashmale=atreatcash*male
    gen atreatequipmale=atreatequip*male
    for num 2/7: gen waveX_female=waveX*female

    gen treatment = atreatcash==1 | atreatequip==1

    keep treatment female wave wave2-wave6 groupnum sheno selfempl any_employment migrate
    gen rct = "Ghana"

    order rct selfempl any_employment migrate

    save "$working_dir/temp/ghana", replace
end

* Execute
main
