clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/RCTs/replication_data"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    use sheno mamount mmale using "$raw_data_dir/McKenzie_SriLanka_Grants/raw_data/sciencerepdata.dta", clear
    duplicates drop
    rename mmale male
    save "$working_dir/temp/slms_shenoList_no_tsunami", replace

    import excel "$raw_data_dir/McKenzie_SriLanka_Grants/SLMS_Migration_08082019.xlsx", ///
        sheet("Status down 5yrs & 10 yrs time") cellrange(A3:BM682) firstrow clear
    
    drop if sheno == .
    keep sheno AA AX
    rename (AA AX) (status_5yr status_10yr)

    * Consider only migration to other district
    foreach fup in 5yr 10yr {
        gen within_distr_migrate_`fup' = status_`fup'==2 | status_`fup'==3 | status_`fup'==4
        * Drop if deceased, unknown location or survey not completed
        replace within_distr_migrate_`fup' = . if status_`fup'==5 | status_`fup'==6 | status_`fup'==7

        gen migrate_`fup' = status_`fup'==3 | status_`fup'==4
        replace migrate_`fup' = . if status_`fup'==5 | status_`fup'==6 | status_`fup'==7
    }

    save "$working_dir/temp/mckenzie_slsms_migr", replace

    use sheno wave max_closed_business wage_worker using ///
        "$raw_data_dir/McKenzie_SriLanka_Grants/raw_data/sciencerepdata.dta", clear

    gen endline = 1
    keep if wave==13
    drop wave

    gen selfempl = 1 - max_closed_business

    append using "$raw_data_dir/McKenzie_SriLanka_Grants/raw_data/SLMS R15 March 2016 Dataset 20160707.dta", ///
        keep(sheno q1_4 qf_5* q3_1 q3_2 q6_6a)

    replace endline = 2 if endline==.

    /*  Direct question of business ownership q1_4 sometimes not
        in agreement with information in intro section
        (validated by looking at qf_8_info)

        We therefore use only the question on current activity in intro section
    */

    replace selfempl = 1 if (qf_5_1==1 | qf_5_2==1) & selfempl==.
    * For those overseas or moved to a different city check business income in previous month
    replace selfempl = 1 if (qf_5_5==1 | qf_5_6==1) & q6_6a!=. & selfempl==.
    * Not operating if enaged in wage work, agricultural work or not working
    replace selfempl = 0 if (qf_5_3==1 | qf_5_4==1| qf_5_7==1) & selfempl==.
    * Non business owners
    replace selfempl = 0 if q3_1!=. & selfempl==.
    * For all remaining obs, look at profits in previous month
    replace selfempl = 1 if q6_6a!=. & selfempl==.

    * Fix those passed away or uncertain according to proxy respondents
    replace selfempl = . if qf_5_8==1 | qf_5_10==1

    * Wage workers
    replace wage_worker = 1 if qf_5_3==1 & wage_worker==.

    egen any_employment = rowmax(wage_worker selfempl)
    replace any_employment = 1 if q3_1==1 & endline==2

    merge m:1 sheno using "$working_dir/temp/mckenzie_slsms_migr", ///
        assert(2 3) keep(3) nogen

    * Set to missing if respondent has passed away
    foreach var in selfempl wage_worker any_employment {
        replace `var' = . if status_5yr==5
    }

    gen migrate = migrate_5yr if endline==1
    replace migrate = migrate_10yr if endline==2

    save "$working_dir/temp/mckenzie_slsms_all", replace

    merge m:1 sheno using "$working_dir/temp/slms_shenoList_no_tsunami", ///
        assert(1 3) keep(3) nogen

    keep selfempl any_employment migrate mamount male endline
    gen rct = "SLMS"

    order rct selfempl any_employment migrate

    save "$working_dir/temp/slms", replace
end

* Execute
main
