clear all
set more off
set maxvar 8000

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/RCTs/replication_data"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    use "$raw_data_dir/Blattman_WINGS/2015-0023_data/AEJ applied/data/WINGS.dta", clear

    * Use same controls as in Blattman et al (2016)
    gl controls_wings = "age_bas female hhsize_bas partner_bas onlyearner_bas biochildren_bas nonacholi_bas " + ///
        "stillenrolled_bas attainment_dup_p1e writingskills_bas speakengl_bas trainlength_bas stddigitrecall " + ///
        "pettybiz_dum_bas dugo1_hrs7d_p99_bas duge1_hrs7d_p99_bas casual_hrs7d_p99_bas  brew_hrs7d_p99_bas " + ///
        "buy_hrs7d_p99_bas others_hrs7d_p99_bas chores_hrs7d_p99_bas zero_employment_bas " + ///
        "wealthindex_all_bas cashtotal4w_basp99_1000 otherhh_earnings_bas savingsgroup_bas savings_basp99_1000 " + ///
        "currloans_basp99_1000 creditaccess15_bas creditaccess100_bas " + ///
        "hhsupport_z_bas commparticipation_z_bas neighborsupport_z_bas groupsin_bas comm_maltreat_bas " + ///
        "physemo_abuse_z_bas decision_making_z_bas womens_rights_z_bas relatedchief_bas " + ///
        "healthindex_bas hiv_bas APAI_R_z_bas " + ///
        "war_exper_bas_z recruited_bas carriedgun_bas forciblymarried_bas borechild_bas " + ///
        "risk_aversion_bas patience_zscore " + ///
        "vilpopulation c_np_educ2 siteid_sample_p1 remoteness pricelevel rentland_sq camp ngo_total " + ///
        "c_vending_p99 c_kiosk_p99 c_shops_p99 c_tailoring_p99 c_hotel_p99 c_othercommarket distancetocapital district1 " + /// 
        "D_T_bar_4_b50 D_T_4_b50"

    gen migrate = 1 - moved_dup_p1e
    label var migrate "Not living in same location as last interview"

    rename biznow_p1e selfempl

    * Note: some of this is in agriculture despite paper says "non-farm selfemployment"
    tab main_agricultural_p1e selfempl if sample_p1 == 1 & found_p1e == 1

    gen any_employment = 1 if total_hrs4w_s2p99_p1e>0 & total_hrs4w_s2p99_p1e!=.
    replace any_employment = 0 if total_hrs4w_s2p99_p1e == 0

    label var any_employment "Any employment"

    * Drop 3 deaths in control group
    drop if sample_p1 == 1 & migrate != . & selfempl == .

    keep selfempl any_employment migrate sample_p1 found_p1e assigned_p1 assigned_p1 assigned_p1_gd siteid $controls_main
    gen rct = "WINGS"

    order rct selfempl any_employment migrate

    save "$working_dir/temp/wings", replace
end

* Execute
main
