clear all
set more off
set maxvar 120000

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/RCTs/replication_data"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    define_globals
    build_migr_2to4y
    build_migr_9y
    preclean
end

program define_globals
    * Use same controls as in Blattman et al (2014)
    gl controls_yop = "D_1-D_13 " + /// 
        "age age_2 age_3 urban ind_found_b risk_aversion " + ///
        "education literate voc_training numeracy_numcorrect_m adl " + ///
        "wealthindex savings_6mo_p99 cash4w_p99 loan_100k loan_1mil " + ///
        "lowskill7da_zero lowbus7da_zero skilledtrade7da_zero highskill7da_zero acto7da_zero " + ///
        "aghours7da_zero chores7da_zero zero_hours nonag_dummy emplvoc inschool " + ///
        "admin_cost_us groupsize_est_e grantsize_pp_US_est3 group_existed group_age " + ///
        "ingroup_hetero ingroup_dynamic grp_leader grp_chair avgdisteduc"

    // OUTCOMES
    gl outcomes_intensive_yop = "totalhrs7da_zero_e aghours7da_zero_e nonaghours7da_zero_e lowskill7da_zero_e " + ///
        "highskill7da_zero_e skilledtrade7da_zero_e zero_hours_e nonag_dummy_e trade_dummy_e fulltimeskill_e"
end

program build_migr_2to4y
    use partid q295a q297 q297a q304a q306_e q306a_e endline using ///
        "$raw_data_dir/Blattman_YOP/YOP9 - Quantitative Analysis/datasets/yop2_yop4.dta" if endline==1, clear

    gen district_b = q295a
    replace district_b = q297a if q297==2

    gen district_e = q304a
    replace district_e = q306a_e if q306_e=="N" & q306a_e!="."

    foreach var in district_b district_e {
        replace `var' = lower(`var')
        replace `var' = stritrim(strtrim(`var'))
    }

    matchit district_b district_e, gen(similscore_dist)

    gen district_migrate_e = similscore_dist < 0.25
    replace district_migrate_e = . if district_e==""

    keep partid district_migrate_e
    save "$working_dir/temp/yop_migration_2y", replace

    use partid q295a q297 q297a endline using ///
        "$raw_data_dir/Blattman_YOP/YOP9 - Quantitative Analysis/datasets/yop2_yop4.dta" if endline==2, clear
    merge 1:1 partid using "$raw_data_dir/Blattman_YOP/YOP9 - Quantitative Analysis/datasets/endline2_indiv_clean.dta", ///
        keepusing(pdistrict) assert(1 2 3) keep(3)

    gen district_b = q295a
    replace district_b = q297a if q297==2

    rename pdistrict district_e

    foreach var in district_b district_e {
        replace `var' = lower(`var')
        replace `var' = stritrim(strtrim(`var'))
    }

    matchit district_b district_e, gen(similscore_dist)

    gen district_migrate_e = similscore_dist < 0.3
    replace district_migrate_e = . if district_e==""

    keep partid district_migrate_e
    save "$working_dir/temp/yop_migration_4y", replace
end

program build_migr_9y
    use partid last_parish parish_correct_spec parish_correct parish last_district district_correct_spec district_correct district using ///
        "$raw_data_dir/Blattman_YOP/YOP9 - Quantitative Analysis/datasets/endline3_indiv_clean.dta", clear

    foreach var in parish district {
        gen `var'_e = last_`var'
        replace `var'_e = `var'_correct_spec if `var'_correct == 0
    }
    rename (parish district) (parish_b district_b)

    foreach var in parish_b parish_e district_b district_e {
        replace `var' = lower(`var')
        replace `var' = stritrim(strtrim(`var'))
    }

    matchit parish_b parish_e, gen(similscore_par)
    matchit district_b district_e, gen(similscore_dist)

    foreach stub in e b {
        gen parish_`stub'_sound = soundex(parish_`stub')
        gen parish_`stub'_sound_init =  substr(parish_`stub'_sound, 1, 3)
    }
    
    gen match_sound = parish_e_sound_init == parish_b_sound_init

    gen migrate_e = 1 if parish_b != parish_e & parish_e != "" & parish_b != ""
    replace migrate_e = 0 if similscore_par >= 0.5
    replace migrate_e = 0 if migrate_e == 1 & similscore_par >= 0.3 & ///
        (similscore_dist >= 0.3 | district_b == "" | district_e == "")
    replace migrate_e = 0 if match_sound == 1

    replace migrate_e = 1 if strpos(parish_e, "east") > 0 & strpos(parish_b, "west") > 0 | ///
        strpos(parish_b, "east") > 0 & strpos(parish_e, "west") > 0

    gen district_migrate_e = similscore_dist < 0.5
    replace district_migrate_e = . if district_e==""

    keep partid migrate_e district_migrate_e
    save "$working_dir/temp/yop_migration_9y", replace
end

program preclean
    use "$raw_data_dir/Blattman_YOP/YOP9 - Quantitative Analysis/datasets/final_end3_end2_end1.dta", clear
    egen wageworker_hours = rowmax(teach7da_zero_e healthngo7da_zero_e military7da_zero_e comp7da_zero_e govt7da_zero_e)
    gen wageworker = wageworker_hours > 0 & wageworker_hours != .

    tab endline, gen(e)

    merge m:1 partid using "$working_dir/temp/yop_migration_9y", ///
        nogen assert(1 2 3) keep(1 3)

    rename (migrate_e district_migrate_e) (migrate_e3 district_migrate_e3)

    merge 1:1 partid e1 e2 using "$raw_data_dir/Blattman_YOP/dataverse_files/yop_analysis.dta", ///
        nogen assert(1 3) keep(1 3) keepusing(migrate_e)

    rename migrate_e migrate
    replace migrate = migrate_e3 if e3 == 1
    drop migrate_e3 district_migrate_e3
    * Up to here

    * Build extensive margin outcomes
    gen any_employment = 1 if totalhrs7da_zero_e > 0 & totalhrs7da_zero_e != .
    replace any_employment = 0 if totalhrs7da_zero_e == 0
    
    gen agricultural_empl = 1 if aghours7da_zero_e > 0 & aghours7da_zero_e != .
    replace agricultural_empl = 0 if aghours7da_zero_e == 0
    
    gen non_agricultural_empl = 1 if nonaghours7da_zero_e > 0 & nonaghours7da_zero_e != .
    replace non_agricultural_empl = 0 if nonaghours7da_zero_e == 0

    gen selfempl = 1 if nonaghours7da_zero_e > 0 & nonaghours7da_zero_e != . & wageworker == 0
    replace selfempl = 0 if nonaghours7da_zero_e == 0 | wageworker == 1

    keep selfempl any_employment migrate w_sampling_e weight district groupid e1 e2 e3 ///
        assigned female $outcomes_intensive_yop $controls_yop
    gen rct = "YOP"

    order rct selfempl any_employment migrate

    save "$working_dir/temp/yop", replace
end

* Execute
main
