clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/RCTs/replication_data"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"


**** First use AER replication file to get impact on self-employment (business open and surviving) and any paid employment

** Set working directory
cd "$raw_data_dir/McKenzie_YouWin/AERReplicationFiles/data/"


program main
    *** Merge together the baseline and three follow-ups
    use "BaselineandFirstFollowup.dta", clear
    cap drop _merge
    merge uid using "SecondFollowup.dta", sort
    drop _merge
    merge uid using "ThirdFollowup.dta", sort

    ** merge in extra variables needed that had been dropped
    drop _merge
    merge uid using "ExtraVarsNeeded.dta", sort
    drop _merge

    /*
    *** merge in round 1 attrition data
    sort uid
    merge uid using "C:\Users\wb200090\OneDrive - WBG\otherresearch\Nigeria\MigrationandYouWin\R1attritmigration.dta"
    tab _merge
    */

    *** append round 4 data
    cap drop _merge
    sort uid
    merge uid using "$raw_data_dir/McKenzie_YouWin/R4data.dta"
    tab _merge


    *** Gender
    drop female
    gen female=sex=="Female"

    *** Just keep experimental sample
    keep if assigntreat~=.


    *** Currently Operate a firm at midline
    gen m_operatefirm=m_q1==1
    replace m_operatefirm=. if m_q1==.
    replace m_operatefirm=1 if m_a3==1 & m_operatefirm==.
    replace m_operatefirm=0 if m_a3==2 & m_operatefirm==.
    replace m_operatefirm=1 if h_oper=="YES"
    replace m_operatefirm=0 if h_oper=="NO"|h_oper=="NONE"
    label var m_operatefirm "Owner operates a firm in midline"

    *** Currently operates a firm at second follow-up
    gen s_operatefirm= s_sc==1
    replace s_operatefirm=. if  s_sc==.
    replace s_operatefirm=1 if s_operate==1 & s_operatefirm==.
    replace s_operatefirm=0 if s_operate==2 & s_operatefirm==.
    replace s_operatefirm=1 if s_a3==1 & s_operatefirm==.
    replace s_operatefirm=0 if s_a3==2 & s_operatefirm==.
    label var s_operatefirm "Operates a firm at time of second follow-up"

    *** Currently operate a firm at third follow-up
    gen t_operatefirm=t_sc==1
    replace t_operatefirm=. if t_sc==.
    replace t_operatefirm=1 if t_operatefirm==. & t_operate==1
    replace t_operatefirm=0 if t_operatefirm==. & t_operate==2
    replace t_operatefirm=1 if t_a3==1 & t_operatefirm==.
    replace t_operatefirm=0 if t_a3==2 & t_operatefirm==.
    label var t_operatefirm "Operates a firm at time of third follow-up"


    *** Currently operate a firm at fourth follow-up
    gen f_operatefirm=f_sc==1
    replace f_operatefirm=. if f_sc==.
    replace f_operatefirm=1 if f_operatefirm==. & f_operate==1
    replace f_operatefirm=0 if f_operatefirm==. & f_operate==2 
    replace f_operatefirm=1 if f_A3==1 & f_operatefirm==.
    replace f_operatefirm=0 if f_A3==2 & f_operatefirm==.
    replace f_operatefirm=0 if f_operatefirm==. & f_phone_operate=="No"
    replace f_operatefirm=1 if f_operatefirm==. & f_phone_operate=="Yes"
    label var f_operatefirm "Operates a firm at time of fourth follow-up"

    * no data on whether they operate a firm
    gen miss_m_operate=m_operatefirm==.
    label var miss_m_operate "No data on whether operate a firm in first follow-up"
    gen miss_s_operate=s_operatefirm==.
    label var miss_s_operate "No data on whether operate a firm in second follow-up"
    sum miss_s_operate
    gen miss_t_operate=t_operatefirm==.
    label var miss_t_operate "No data on whether operate a firm in third follow-up"
    sum miss_t_operate 
    gen miss_f_operate=f_operatefirm==.
    label var miss_f_operate "No data on whether operate a firm in fourth follow-up"
    sum miss_f_operate
    bysort group: sum miss_m_operate miss_s_operate miss_t_operate miss_f_operate


    * Business owner is employed
    gen m_employed=m_operatefirm==1 
    replace m_employed=. if m_operatefirm==.
    replace m_employed=1 if m_k11_1<=5
    label var m_employed "Individual is employed at first follow-up"

    gen s_employed=s_operatefirm==1
    replace s_employed=. if s_operatefirm==.
    * a bug in the recording of s_nb1, so using hours worked in job as indicator of whether they have one
    replace s_employed=1 if s_nb3~=.
    label var s_employed "Individual is employed at second follow-up"

    gen t_employed=t_operatefirm==1
    replace t_employed=. if t_operatefirm==.
    replace t_employed=1 if t_nb1_1==1|t_nb1_2==1|t_nb1_3==1|t_nb1_4==1|t_nb1_5==1
    replace t_employed=0 if t_nb1_6==1
    label var t_employed "Individual is employed at third follow-up"

    gen f_employed=f_operatefirm==1
    replace f_employed=. if f_operatefirm==.
    replace f_employed=1 if f_NB1_1==1|f_NB1_2==1|f_NB1_3==1|f_NB1_4==1|f_NB1_5==1
    replace f_employed=0 if f_NB1_6==1
    label var f_employed "Individual is employed at fourth follow-up"


    *** Treatment strata
    egen strata=group(region existing female)
    replace strata=. if experimentalsample~=1



    **** First Stage: Impact on Self-Employment and Paid Employment
    rename (m_operatefirm s_operatefirm t_operatefirm f_operatefirm) ///
        (m_selfempl s_selfempl t_selfempl f_selfempl)
    rename (m_employed s_employed t_employed f_employed) ///
        (m_any_employment s_any_employment t_any_employment f_any_employment)


    ****** Now Get Migration (Internal and International) Outcome

    *** Round 1 doesn't directly ask about it, and issues with not being able to know whether put business location, home location, or ancestral location on baseline application form

    *** Round 2 Migration
    gen s_anymigration=0 if s_p2==1
    replace s_anymigration=1 if s_p2==2|s_p2==3
    replace s_anymigration=1 if s_anymigration==. & (s_dm6==66|s_a1==3|s_a5==2|s_a5==3)
    replace s_anymigration=0 if s_anymigration==. & (s_a5==1)

    * International migration
    gen s_int_migration=0 if s_p2==1
    replace s_int_migration=1 if s_p2==3
    replace s_int_migration=1 if s_int_migration==. & (s_dm6==66|s_a5==3)
    replace s_int_migration=0 if s_int_migration==. & (s_a5==1)

    *** Round 3
    gen t_anymigration=0 if t_p2==1
    replace t_anymigration=1 if t_p2==2|t_p2==3
    replace t_anymigration=1 if t_anymigration==. & (t_dm6==66|t_a1==3|t_a5==2|t_a5==3)
    replace t_anymigration=0 if t_anymigration==. & (t_a5==1)

    * International migration
    gen t_int_migration=0 if t_p2==1
    replace t_int_migration=1 if t_p2==3
    replace t_int_migration=1 if t_int_migration==. & (t_dm6==66|t_a5==3)
    replace t_int_migration=0 if t_int_migration==. & (t_a5==1)

    **** Round 4
    gen f_anymigration=t_anymigration if f_P2==1
    replace f_anymigration=1 if f_P2==2
    replace f_anymigration=1 if f_anymigration==. & (f_A1==3|f_A5==2|f_A5==3)
    * issue is firms with R3 migration missing-  use R2 status if say haven't moved in last 2 years
    replace f_anymigration=0 if f_P2==1 & f_anymigration==. & s_anymigration==0
    replace f_anymigration=1 if f_P2==1 & f_anymigration==. & s_anymigration==1

    * International migration
    gen f_int_migration=t_int_migration
    replace f_int_migration=0 if f_P2!=.
    replace f_int_migration=1 if f_int_migration==. & f_A5==3



    rename (s_anymigration t_anymigration f_anymigration) ///
        (s_migrate t_migrate f_migrate)

    keep *migrate *selfempl *any_employment assigntreat experimentalsample strata
    gen rct = "YouWin"

    order rct *selfempl *any_employment *migrate

    save "$working_dir/temp/youwin", replace
end

* Execute
main
