clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/descriptive"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    use pid provcd countyid psu gender qa1age cfps2010eduy_best qg3 qg303 qg4 income using ///
        "$raw_data_dir/raw_data/CFPS/[CFPS Public Data] CFPS2010 in STATA (English)/ecfps2010adult_201906.dta" ///
        if pid != ., clear

    rename (provcd countyid qa1age cfps2010eduy_best qg3 qg303 qg4) ///
        (province_2010 county_2010 age educyears has_job_2010 job_2010 primary_job_2010_agri)

    local keep_vars "provcd16 countyid16 jobclass rswt_natpn1016 rswt_respn1016 ear1 ear101a ear102 ear201a ear2 employ"
    
    merge 1:m pid using "$raw_data_dir/raw_data/CFPS/[CFPS Public Data] CFPS2016 in STATA (English)/ecfps2016adult_201906.dta", ///
        keepusing(`keep_vars') assert(1 2 3) keep(3) nogen

    rename (provcd16 countyid16 jobclass employ) (province_2016 county_2016 job_2016 has_job_2016)

    gen female = gender == 0
    gen ln_income = ln(income)

    drop if age < 18 | age > 65

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    * Compute migration variables
    foreach var in province county {
        gen `var'_migr_1stFup = `var'_2010 != `var'_2016
        replace `var'_migr_1stFup = . if `var'_2016 == -9
    }
    replace county_migr_1stFup = 0 if province_migr_1stFup==1
    
    egen any_migr_1stFup = rowmax(province_migr_1stFup county_migr_1stFup)
    gen internal_migr_1stFup = any_migr_1stFup

    * Compute employment variables
    gen not_working_base = has_job_2010 == 0
    replace not_working_base = . if has_job_2010 == -8

    gen self_empl_base = job_2010 == 1 & primary_job_2010_agri != 1
    replace self_empl_base = . if job_2010 == -2 | job_2010 == -1 | not_working_base == .

    gen wage_worker_base = job_2010 == 3 & primary_job_2010_agri != 1
    replace wage_worker_base = . if job_2010 == -2 | job_2010 == -1 | not_working_base == .

    gen agri_worker_base = job_2010 == 5
    replace agri_worker_base = . if job_2010 == -2 | job_2010 == -1 | not_working_base == .

    gen self_empl_1stFup = job_2016 == 2 & has_job_2016 > 0
    gen wage_worker_1stFup = job_2016 == 4 & has_job_2016 > 0
    gen agri_worker_1stFup = (job_2016 == 1 | job_2016 == 3) & has_job_2016 > 0
    gen not_working_1stFup = self_empl_1stFup == 0 & wage_worker_1stFup == 0 & agri_worker_1stFup == 0 & has_job_2016 != 1

    gen occupation = 0 if not_working_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 2 if wage_worker_base == 1
    replace occupation = 3 if agri_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker" 3 "Agricultural worker"
    label values occupation occupation

    gen country = "China"
    tostring pid, gen(person_id)

    keep person_id female educyears age_group income occupation country ///
        any_migr_1stFup internal_migr_1stFup province_migr_1stFup county_migr_1stFup ///
        self_empl_1stFup wage_worker_1stFup agri_worker_1stFup not_working_1stFup

    isid person_id
    save "$working_dir/temp/cfps_master", replace
end

* Execute
main
