clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/descriptive"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    use "$raw_data_dir/raw_data/ELMPS/elmps 2012 panel 98_12 v2.2.dta", clear

    rename (age_98 yrschl_98) (age educyears)
    drop if age < 18 | age > 65

    gen female = sex_98 == 2

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    * Compute migration variables
    foreach year in 98 06 12 {
        gen gov_`year'_str = string(gov_`year') if gov_`year'!=.
        gen qism_`year'_str = string(gov_`year') + string(qism_`year') if gov_`year'!=.  & qism_`year'!=.
        gen shyakha_`year'_str = string(gov_`year') + string(qism_`year') + string(shyakha_`year') if ///
            gov_`year'!=. & qism_`year'!=. & shyakha_`year'!=.

        drop gov_`year' qism_`year' shyakha_`year'
    }
    
    foreach endyear in 06 12 {
        if "`endyear'" == "06" local fup "1stFup"
        else if "`endyear'" == "12" local fup "2ndFup"

        gen gov_migr_`fup' = gov_98_str!=gov_`endyear'_str
        replace gov_migr_`fup' = . if gov_98_str=="" | gov_`endyear'_str==""

        gen qism_migr_`fup' = qism_98_str!=qism_`endyear'_str & gov_98_str==gov_`endyear'_str
        replace qism_migr_`fup' = . if qism_98_str=="" | qism_`endyear'_str==""

        gen shyakha_migr_`fup' = shyakha_98_str!=shyakha_`endyear'_str & qism_98_str==qism_`endyear'_str
        replace shyakha_migr_`fup' = . if shyakha_98_str=="" | shyakha_`endyear'_str==""

        egen any_migr_`fup' = rowmax(gov_migr_`fup' qism_migr_`fup' shyakha_migr_`fup')
        gen internal_migr_`fup' = any_migr_`fup'
    }

    foreach year in 98 06 12 {
        if "`year'" == "98" local fup "base"
        else if "`year'" == "06" local fup "1stFup"
        else if "`year'" == "12" local fup "2ndFup"

        gen not_working_`fup' = usemp1_`year' == 0
        replace not_working_`fup' = . if usemp1_`year' == .

        gen self_empl_`fup' = (usempstp_`year' == 3 | usempstp_`year' == 2) & usecac1d_cl_`year' != 0
        gen wage_worker_`fup' = usempstp_`year' == 1 & usecac1d_cl_`year' != 0
        gen agri_worker_`fup' = usecac1d_cl_`year' == 0

        foreach var in self_empl_`fup' wage_worker_`fup' agri_worker_`fup' {
            replace `var' = . if usempstp_`year' == . | usecac1d_cl_`year' == .
            replace `var' = 0 if not_working_`fup' == 1
        }
        replace not_working_`fup' = 0 if not_working_`fup' == . & self_empl_`fup' != .
        replace not_working_`fup' = . if self_empl_`fup' == . & wage_worker_`fup' == .
    }

    gen occupation = 0 if not_working_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 2 if wage_worker_base == 1
    replace occupation = 3 if agri_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker" 3 "Agricultural worker"
    label values occupation occupation

    rename indid_98 indid
    save "$working_dir/temp/elmps_master", replace

    use "$raw_data_dir/raw_data/ELMPS/elms98_Inddata", clear

    foreach job in main other {
        if "`job'" == "main" local jobvar 4104
        else if "`job'" == "other" local jobvar 4203

        foreach wagetype in a b c d e f g {
            gen wage_`jobvar'`wagetype' = q`jobvar'`wagetype'2*20 if q`jobvar'`wagetype'1 == 1
            replace wage_`jobvar'`wagetype' = q`jobvar'`wagetype'2*4 if q`jobvar'`wagetype'1 == 2
            replace wage_`jobvar'`wagetype' = q`jobvar'`wagetype'2 if q`jobvar'`wagetype'1 == 3
            replace wage_`jobvar'`wagetype' = q`jobvar'`wagetype'2/3 if q`jobvar'`wagetype'1 == 4
            replace wage_`jobvar'`wagetype' = q`jobvar'`wagetype'2/12 if q`jobvar'`wagetype'1 == 5
        }
    }
    gen wage_irreg = q4109_1*20
    egen income = rowtotal(wage_4104* wage_4203*)

    gen ln_income = ln(income)

    keep income ln_income indid

    merge 1:1 indid using "$working_dir/temp/elmps_master", ///
        nogen assert(1 3) keep(3)

    rename indid person_id
    gen country = "Egypt"

    keep person_id female educyears age_group income occupation country ///
        any_migr_1stFup internal_migr_1stFup any_migr_2ndFup internal_migr_2ndFup ///
        gov_migr_1stFup qism_migr_1stFup shyakha_migr_1stFup ///
        self_empl_1stFup wage_worker_1stFup agri_worker_1stFup not_working_1stFup ///
        gov_migr_2ndFup qism_migr_2ndFup shyakha_migr_2ndFup ///
        self_empl_2ndFup wage_worker_2ndFup agri_worker_2ndFup not_working_2ndFup

    isid person_id
    save "$working_dir/temp/elmps_master", replace
end

* Execute
main
