clear all
set more off

global data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/AnnaLuisaFiles/Migration of the self-employed/Data/IFLS"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    * IFLS 3
    use "$data_dir/round 3/hh00dta/b3a_tk1.dta", clear
    merge 1:1 pidlink using "$data_dir/round 3/hh00dta/b3a_tk2.dta", ///
        nogen assert(1 3) keep(1 3)
    merge 1:1 pidlink using "$data_dir/round 3/hh00dta/b3p_tk1.dta", ///
        nogen assert(1 2 3) keep(1 2 3)
    merge 1:1 pidlink using "$data_dir/round 3/hh00dta/b3p_tk2.dta", ///
        nogen assert(1 2 3) keep(1 2 3)

    gen not_working_base = 1 if tk01!=1 & tk19aa=="" & tk24a==.
    replace not_working_base = 0 if tk01==1 | tk19aa!="" | tk24a!=.

    gen self_empl_base = 1 if (tk24a==1 | tk24a==2 | tk24a==3) & tk19aa!="1"
    replace self_empl_base = 0 if (tk24a!=1 & tk24a!=2 & tk24a!=3) | tk19aa=="1"
    lab var self_empl_base "Was self-employed during reference period"

    gen wage_worker_base = 1 if (tk24a==4 | tk24a==5) & tk19aa!="1"
    replace wage_worker_base = 0 if (tk24a!=4 & tk24a!=5) | tk19aa=="1"
    lab var wage_worker_base "Worked as wage worker during reference period"

    gen agri_worker_base = 1 if tk19aa=="1"
    replace agri_worker_base = 0 if tk19aa!="1"

    gen occupation = 0 if not_working_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 2 if wage_worker_base == 1
    replace occupation = 3 if agri_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker" 3 "Agricultural worker"
    label values occupation occupation

    gen profit = tk26ayn
    replace profit = tk26ayg if profit == . & tk26ayg != .
    
    egen income = rowtotal(tk25a2 profit)
    replace income = . if income == 0 & not_working_base == 0
    gen ln_income = ln(income)

    merge 1:1 hhid00 pid00 using "$data_dir/round 3/hh00dta/bk_ar1.dta", ///
        nogen assert(2 3) keep(3)

    rename (ar09 ar07) (age sex)
    gen female = sex == 3

    drop if age < 18 | age > 65

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    * Compute years of education
    * I did not consider: Adult Education A (11), Adult Education B (12), 13 Open University (13), Islamic School (14), School for the Disabled (17), Madrasah (70), Other (10)
    * Sources:   https://www.nuffic.nl/en/publications/find-a-publication/education-system-indonesia.pdf
    *            https://en.wikipedia.org/wiki/Education_in_Indonesia
    gen educyears=0 if ar16==1 | ar16==90 | ar17==96
    *Elementary School
    replace educyears=ar17 if (ar16==2 | ar16==72)
    replace educyears=6 if ar17==7 & (ar16==2 | ar16==72)
    *Junior High
    replace educyears=ar17+6 if (ar16==3 | ar16==4 | ar16==73)
    replace educyears=3+6 if ar17==7 & (ar16==3 | ar16==4 | ar16==73)
    *High School
    replace educyears=ar17+9 if (ar16==5 | ar16==6 | ar16==74)
    replace educyears=3+9 if ar17==7 & (ar16==5 | ar16==6 | ar16==74)
    *Tertiary education
    replace educyears=ar17+12 if (ar16==60 | ar16==61)
    replace educyears=4+12 if ar17==7 & (ar16==60 | ar16==61)
    replace educyears=ar17+16 if (ar16==62)
    replace educyears=2+16 if ar17==7 & (ar16==62)
    replace educyears=ar17+18 if (ar16==63)
    replace educyears=3+16 if ar17==7 & (ar16==63)
    replace educyears=. if ar16==98 | ar17==98 | educyears > 100
    label var educyears "Person's education in years"

    keep hhid00 pidlink not_working_base self_empl_base wage_worker_base agri_worker_base ///
        ln_income income age_group educyears female occupation

    * IFLS 4
    merge 1:1 pidlink using "$data_dir/round 4/hh07_all_dta/b3a_tk2.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(hhid07 tk24a tk19ab)
    merge 1:1 pidlink using "$data_dir/round 4/hh07_all_dta/bp_tk2.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(hhid07 tk24b tk19bb)
    merge 1:1 pidlink using "$data_dir/round 4/hh07_all_dta/b3a_tk1.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(hhid07 tk01)
    
    destring tk19ab, replace
    replace tk24a = tk24b if tk24a==. & tk24b!=.
    replace tk19ab = tk19bb if tk19ab==. & tk19bb!=.
    
    gen not_working_1stFup = 1 if tk01!=1 & tk19ab==. & tk24a==.
    replace not_working_1stFup = 0 if tk01==1 | tk19ab!=. | tk24a!=.
    
    gen self_empl_1stFup = 1 if (tk24a==1 | tk24a==2 | tk24a==3) & tk19ab!=1
    replace self_empl_1stFup = 0 if (tk24a!=1 & tk24a!=2 & tk24a!=3) | tk19ab==1

    gen wage_worker_1stFup = 1 if (tk24a==4 | tk24a==5) & tk19ab!=1
    replace wage_worker_1stFup = 0 if (tk24a!=4 & tk24a!=5) | tk19ab==1

    gen agri_worker_1stFup = 1 if tk19ab==1
    replace agri_worker_1stFup = 0 if tk19ab!=1

    drop tk01 tk24a tk19ab tk24b tk19bb
    save "$working_dir/temp/ifls", replace

    * Check if abroad using control book
    use pidlink ar18i ar18h ar18eyr ar18emth using ///
        "$data_dir/round 4/hh07_all_dta/bk_ar1.dta", clear

    bys pidlink (ar18eyr ar18emth): gen max_instance = _N
    bys pidlink (ar18eyr ar18emth): gen instance = _n

    keep if instance == max_instance
    
    gen international_migr_1stFup = ar18eyr>=2000 & ar18i>=100 & ar18i<=995
    replace international_migr_1stFup = . if ar18eyr>=2000 & ar18i==998

    merge 1:1 pidlink using "$working_dir/temp/ifls", ///
        nogen assert(1 2 3) keep(2 3)

    * IFLS 5
    merge 1:1 pidlink using "$data_dir/round 5/hh14_all_dta/b3a_tk2.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(hhid14 tk19ab tkp19aa tk24a)
    merge 1:1 pidlink using "$data_dir/round 5/hh14_all_dta/b3a_tk1.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(hhid14 tk01)

    replace tk19ab = tkp19aa if tkp19aa != . & tk19ab == .

    gen not_working_2ndFup = 1 if tk01!=1 & tk19ab==. & tk24a==.
    replace not_working_2ndFup = 0 if tk01==1 | tk19ab!=. | tk24a!=.

    gen self_empl_2ndFup = 1 if (tk24a==1 | tk24a==2 | tk24a==3) & tk19ab!=1
    replace self_empl_2ndFup = 0 if (tk24a!=1 & tk24a!=2 & tk24a!=3) | tk19ab==1

    gen wage_worker_2ndFup = 1 if (tk24a==4 | tk24a==5) & tk19ab!=1
    replace wage_worker_2ndFup = 0 if (tk24a!=4 & tk24a!=5) | tk19ab==1

    gen agri_worker_2ndFup = 1 if tk19ab==1
    replace agri_worker_2ndFup = 0 if tk19ab!=1

    drop tk19ab tkp19aa tk24a
    save "$working_dir/temp/ifls", replace

    * Check if abroad using control book
    use pidlink ar18i ar18h ar18eyr ar18emth using ///
        "$data_dir/round 5/hh14_all_dta/bk_ar1.dta", clear

    bys pidlink (ar18eyr ar18emth): gen max_instance = _N
    bys pidlink (ar18eyr ar18emth): gen instance = _n

    keep if instance == max_instance

    merge 1:1 pidlink using "$working_dir/temp/ifls", ///
        nogen assert(1 2 3) keep(2 3)
    
    gen international_migr_2ndFup = international_migr_1stFup 
    replace international_migr_2ndFup = 1 if ar18eyr>=2007 & ar18i>=100 & ar18i<=995
    replace international_migr_2ndFup = 0 if ar18eyr>=2007 & ar18i<100
    replace international_migr_2ndFup = . if ar18eyr>=2000 & ar18i==998

    save "$working_dir/temp/ifls", replace
    
    * Merge to location data
    use "$data_dir/round 5/hh14_all_dta/htrack.dta" if hhid00 != "", clear
    keep hhid00 sc030000 sc020000 sc010000
    rename (sc030000 sc020000 sc010000) (sc03_00_00 sc02_00_00 sc01_00_00)

    duplicates drop

    merge 1:m hhid00 using "$working_dir/temp/ifls", ///
        nogen assert(1 3) keep(3)
    save "$working_dir/temp/ifls_location1", replace

    use "$data_dir/round 5/hh14_all_dta/htrack.dta" if hhid07 != "", clear
    keep hhid07 sc01_07_00 sc02_07_00 sc03_07_00

    duplicates drop

    merge 1:m hhid07 using "$working_dir/temp/ifls_location1", ///
        nogen assert(1 2 3) keep(2 3)
    save "$working_dir/temp/ifls_location2", replace

    use "$data_dir/round 5/hh14_all_dta/htrack.dta" if hhid14 != "", clear
    keep hhid14 mover07 sc01_14_00 sc02_14_00 sc03_14_00

    duplicates drop

    merge 1:m hhid14 using "$working_dir/temp/ifls_location2", ///
        nogen assert(1 2 3) keep(2 3)

    /*** NOTE ***
    The location in mg1 seems to agree with that in the htrack module 
    (true also for respondents that report incorrect preloaded location)
    Unclear if countries coded as 99 are missing values or foreign countries
    
    After keeping the last migration instance from modul mg2 there is no case
    of international migration between each survey wave
    ***/

    foreach year in 00 07 14 {
        gen province_`year' = string(sc01_`year'_00) if sc01_`year'_00 != .
        gen kab_`year' = string(sc01_`year'_00) + string(sc02_`year'_00) if ///
            sc01_`year'_00 != . & sc02_`year'_00 != .
        gen kec_`year' = string(sc01_`year'_00) + string(sc02_`year'_00) + string(sc03_`year'_00) if ///
            sc01_`year'_00 != . & sc02_`year'_00 != . & sc03_`year'_00 != .
    }

    * Define migration variables
    foreach endyear in 07 14 {

        if "`endyear'" == "07" local fup "1stFup"
        else if "`endyear'" == "14" local fup "2ndFup"

        gen province_migr_`fup' = 1 if province_`endyear' != province_00 & ///
            province_`endyear' != "" & province_00 != ""
        replace province_migr_`fup' = 0 if (province_`endyear' == province_00 & ///
            province_`endyear' != "" & province_00 != "") | international_migr_`fup' == 1

        gen kab_migr_`fup' = 1 if kab_`endyear' != kab_00 & ///
            kab_`endyear' != "" & kab_00 != ""
        replace kab_migr_`fup' = 0 if (kab_`endyear' == kab_00 & ///
            kab_`endyear' != "" & kab_00 != "") | international_migr_`fup'==1 | province_migr_`fup'==1

        gen kec_migr_`fup' = 1 if kec_`endyear' != kec_00 & ///
            kec_`endyear' != "" & kec_00 != ""
        replace kec_migr_`fup' = 0 if (kec_`endyear' == kec_00 & ///
            kec_`endyear' != "" & kec_00 != "") | international_migr_`fup'==1 | province_migr_`fup'==1 | kab_migr_`fup'==1

        egen internal_migr_`fup' = rowmax(province_migr_`fup' kab_migr_`fup' kec_migr_`fup')

        replace international_migr_`fup' = . if internal_migr_`fup' == .
        replace international_migr_`fup' = 0 if internal_migr_`fup' != . & international_migr_`fup' == .
        egen any_migr_`fup' = rowmax(internal_migr_`fup' international_migr_`fup')
    }

    gen country = "Indonesia"
    rename pidlink person_id

    keep person_id female educyears age_group income occupation country ///
        any_migr_1stFup internal_migr_1stFup international_migr_1stFup ///
        self_empl_1stFup wage_worker_1stFup agri_worker_1stFup not_working_1stFup ///
        province_migr_1stFup kab_migr_1stFup kec_migr_1stFup any_migr_2ndFup internal_migr_2ndFup ///
        international_migr_2ndFup province_migr_2ndFup kab_migr_2ndFup kec_migr_2ndFup ///
        self_empl_2ndFup wage_worker_2ndFup agri_worker_2ndFup not_working_2ndFup

    isid person_id
    save "$working_dir/temp/ifls_master", replace
end

* Execute
main
