clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/descriptive"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    * Load 2005 data
    use "$raw_data_dir/raw_data/IHDS/ICPSR_22626/DS0001/22626-0001-Data", clear
    rename *, lower

    rename (hhid hhsplitid personid) (hhid2005 hhsplitid2005 personid2005)

    foreach var in nf8 nf9 nf17 nf18 nf26 nf27 fm29 fm30 ws8annual ws6year {
        replace `var' = 0 if `var' == .
    }

    * Impute business income
    gen hrs_bus = nf8*nf9 + nf17*nf18 + nf26*nf27

    bys idhh: egen tot_hrs = sum(hrs_bus)
    gen fr_bus_time = hrs_bus/tot_hrs
    replace fr_bus_time = 0 if fr_bus_time == .

    gen inc_bus_inc_0 = fr_bus_time*incbus

    * Impute farm income
    gen hrs_agr = fm29*fm30

    bys idhh: egen tot_hrs_agr = sum(hrs_agr)
    gen fr_agr_time = hrs_agr/tot_hrs_agr
    replace fr_agr_time = 0 if fr_agr_time == .

    gen inc_agr_inc_0 = fr_agr_time*incfarm

    * Compute person income
    gen person_income_05 = inc_bus_inc_0 + ws8annual + inc_agr_inc_0
    recode person_income_05 .= 0

    gen ln_income = ln(person_income_05)

    * Infer primary activity based on hours worked (require at least 240 hours in activity)
    gen self_empl_base = 0
    gen wage_worker_base = 0
    gen agri_worker_base = 0

    replace self_empl_base = 1 if hrs_bus >= 240 & ws6year < 240 & hrs_agr < 240
    replace wage_worker_base = 1 if ws6year >= 240 & hrs_bus < 240 & hrs_agr < 240 & (ws4a < 0 | ws4a > 6)
    replace agri_worker_base = 1 if (hrs_agr >=240 & hrs_bus < 240) | ///
        (ws6year >= 240 & hrs_bus < 240 & ws4a >= 0 & ws4a <= 6)

    gen not_working_base = hrs_bus < 240 & ws6year < 240 & hrs_agr < 240

    rename (ro3 ro5 ed5) (gender age educyears)
    replace educyears = . if educyears < 0

    keep stateid distid psuid hhsplitid2005 personid2005 hhid2005 hhsplitid2005 personid2005 person_income_05 ///
        ln_income self_empl_base wage_worker_base agri_worker_base not_working_base gender age educyears

    gen female = gender == 2
    rename person_income_05 income

    gen occupation = 0 if not_working_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 2 if wage_worker_base == 1
    replace occupation = 3 if agri_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker" 3 "Agricultural worker"
    label values occupation occupation
    
    save "$working_dir/temp/ihds_2005", replace

    * Load tracking file
    use "$raw_data_dir/raw_data/IHDS/ICPSR_36151/DS0011/36151-0011-Data.dta", clear
    rename *, lower

    gen any_migr_1stFup = th12 == 3

    rename (th15 th22) (occupation_migrant place_residence)

    gen sameState_migr_1stFup = th23 == 1
    gen state_migr_1stFup = th23 == 2
    gen international_migr_1stFup = th23 == 3

    egen internal_migr_1stFup = rowmax(sameState_migr_1stFup state_migr_1stFup)

    keep any_migr_1stFup sameState_migr_1stFup state_migr_1stFup international_migr_1stFup ///
        internal_migr_1stFup place_residence occupation_migrant stateid distid psuid hhid hhsplitid personid

    gen self_empl_1stFup = occupation_migrant == 5 | occupation_migrant == 6 | occupation_migrant == 7
    gen wage_worker_1stFup = occupation_migrant == 4 | occupation_migrant == 8
    gen agri_worker_1stFup = occupation_migrant == 1 | occupation_migrant == 2 | occupation_migrant == 3
    gen not_working_1stFup = occupation_migrant >= 10 & occupation_migrant != .

    rename (hhid hhsplitid personid) (hhid2005 hhsplitid2005 personid2005)
    merge 1:1 stateid distid psuid hhid2005 hhsplitid2005 personid2005 ///
        using "$working_dir/temp/ihds_2005", nogen assert(3) keep(3)

    drop if age < 18 | age > 65

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    egen person_id = group(stateid distid psuid hhid2005 hhsplitid2005 personid2005)
    tostring person_id, replace
    
    gen country = "India"

    keep person_id female educyears age_group income occupation country ///
        any_migr_1stFup internal_migr_1stFup international_migr_1stFup ///
        state_migr_1stFup self_empl_1stFup wage_worker_1stFup agri_worker_1stFup not_working_1stFup

    isid person_id
    save "$working_dir/temp/ihds_master", replace
end

* Execute
main
