clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/descriptive"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    build_income

    use pid91_94 hhid2 id2 PID using /// 
        "$raw_data_dir/raw_data/KHDS/TZA_2010_KHDS_v01_M_STATA8/LinkIDs.dta", clear

    gen pid_04 = hhid2 + id2
    drop hhid2 id2
    rename PID pid_10

    save "$working_dir/temp/id_links", replace

    * Create data waves 1991-94
    use district ward vgno cluster hh using ///
        "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/ENUMERATION/ENUM_HH.dta" if hh != ., clear

    rename (ward vgno) (ward_91 village_91)

    decode district, gen(district_91)
    replace district_91 = "BUKOBA RURAL" if district_91 == "BUKOBA_R"
    replace district_91 = "BUKOBA URBAN" if district_91 == "BUKOBA_U"
    replace district_91 = "BIHARAMULO" if district_91 == "BIHARAMU"
    gen region_91 = "KAGERA"

    merge 1:m cluster hh using "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7A__IND.dta", ///
        assert(1 2 3) keep(3) keepusing(id empld7 empld12 ag7 ag12 se7 se12 empldchk) nogen
    merge 1:1 cluster hh id using "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7B__IND.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(emplmnt1)
    merge 1:1 cluster hh id using "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7D__IND.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(selfemp1)
    merge 1:1 cluster hh id using ///
        "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S1___IND.dta", ///
        keepusing(ageyr sex) nogen assert(2 3) keep(3)
    merge 1:1 cluster hh id using ///
        "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7F__IND.dta", ///
        keepusing(mainjob) nogen assert(1 2 3) keep(1 3)
    merge 1:1 cluster hh id using ///
        "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S5___IND.dta", ///
        keepusing(grade) nogen assert(1 2 3) keep(1 3)

    gen self_empl_base = ((se7 == 1 & selfemp1 > 2) | se12 == 1) & mainjob > 2
    replace self_empl_base = . if (se7 == . & se12 == .) | (empld7 == . & empld12 == .) | (ag7 == . & ag12 == .)

    gen wage_worker_base = ((empld7 == 1 & emplmnt1 > 2) | empld12 == 1) & mainjob > 2
    replace wage_worker_base = . if (se7 == . & se12 == .) | (empld7 == . & empld12 == .) | (ag7 == . & ag12 == .)

    gen agri_worker_base = (ag7 == 1 | ag12 == 1) & mainjob <= 2
    replace agri_worker_base = . if (se7 == . & se12 == .) | (empld7 == . & empld12 == .) | (ag7 == . & ag12 == .)

    gen not_working_base = mainjob == 13
    replace not_working_base = . if (se7 == . & se12 == .) | (empld7 == . & empld12 == .) | (ag7 == . & ag12 == .)

    gen occupation = 0 if not_working_base == 1
    replace occupation = 2 if wage_worker_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 3 if agri_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker" 3 "Agricultural worker"
    label values occupation occupation

    * Do not consider Adulted or Koranic
    * Based on https://www.nuffic.nl/documents/475/education-system-tanzania.pdf
    gen educyears = 0 if grade == "." | grade == "NONE"
    forvalues pgrade=1/8 { 
        replace educyears = `pgrade' if grade == "P`pgrade'"
    }
    forvalues sgrade=1/4 {
        replace educyears = 8 + `sgrade' if grade == "S`sgrade'"
    }
    forvalues agrade=1/2 {
        replace educyears = 12 + `agrade' if grade == "A`agrade'"
    }
    forvalues ugrade=1/8 {
        replace educyears = 14 + `ugrade' if grade == "U`ugrade'"
    }

    gen female = sex == 2

    rename ageyr age
    drop if age < 18 | age > 65

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    merge 1:1 cluster hh id using "$working_dir/temp/khds_income", ///
        nogen assert(1 2 3) keep(1 3)

    replace income = 0 if income == .
    gen ln_income = ln(income)

    foreach var in cluster hh id {
        gen `var'_str = string(`var',"%02.0f")
    }
    gen pid91_94 = cluster_str + hh_str + id_str
    
    merge 1:m pid91_94 using "$working_dir/temp/id_links", ///
        assert(1 2 3) keep(3) nogen

    isid pid91_94
    save "$working_dir/temp/khds_1991", replace

    * Create data wave 2004
    use hhid2 country region district si2c using ///
        "$raw_data_dir/raw_data/KHDS/TZA_2004_KHDS_v01_M_STATA/hh.dta", clear

    rename (country region district si2c) (country_04 region_04 district_04 migration_type_1stFup)

    merge 1:m hhid2 using "$raw_data_dir/raw_data/KHDS/TZA_2004_KHDS_v01_M_STATA/sec7.dta", ///
        assert(1 3) keep(3) nogen keepusing(id2 s7aq2 s7aq3 s7aq4 s7aq5 s7aq6 s7aq7 s7dq1b s7fq1b s7bq1b)

    gen self_empl_1stFup = ((s7aq6 == 1 & s7dq1b > 2) | s7aq7 == 1) & s7fq1b > 2
    replace self_empl_1stFup = . if s7aq6 == . & s7aq7 == .

    gen wage_worker_1stFup = ((s7aq2 == 1 & s7bq1b > 2) | s7aq3 == 1) & s7fq1b > 2
    replace wage_worker_1stFup = . if (s7aq6 == . & s7aq7 == .) | (s7aq2 == . & s7aq3 == .) | (s7aq4 == . & s7aq5 == .)
    replace wage_worker_1stFup = 0 if self_empl_1stFup == 1

    gen agri_worker_1stFup = (s7aq4 == 1 | s7aq5 == 1) & s7fq1b <= 2
    replace agri_worker_1stFup = . if (s7aq6 == . & s7aq7 == .) | (s7aq2 == . & s7aq3 == .) | (s7aq4 == . & s7aq5 == .)
    replace agri_worker_1stFup = 0 if self_empl_1stFup == 1

    gen not_working_1stFup = s7fq1b == 13
    replace not_working_1stFup = . if (s7aq6 == . & s7aq7 == .) | (s7aq2 == . & s7aq3 == .) | (s7aq4 == . & s7aq5 == .)
    replace not_working_1stFup = 0 if self_empl_1stFup == 1 | wage_worker_1stFup == 1 | agri_worker_1stFup == 1

    gen pid_04 = hhid2 + id2

    keep pid_04 country_04 region_04 district_04 self_empl_1stFup wage_worker_1stFup agri_worker_1stFup not_working_1stFup migration_type_1stFup

    isid pid_04
    save "$working_dir/temp/khds_2004", replace

    * Create data wave 2010
    use HHID Region District Ward T0Qd using ///
        "$raw_data_dir/raw_data/KHDS/TZA_2010_KHDS_v01_M_STATA8/HHData.dta", clear

    foreach var in Region District Ward {
        decode `var', gen(`var'_dec)
        replace `var'_dec = upper(`var'_dec)
    }

    rename (Region_dec District_dec Ward_dec T0Qd) (region_10 district_10 ward_10 migration_type_2ndFup)

    merge 1:m HHID using "$raw_data_dir/raw_data/KHDS/TZA_2010_KHDS_v01_M_STATA8/hhmember.dta", ///
        assert(1 3) keep(3) nogen keepusing(PID T2dQ01 T2dQ14 T2dQ15 T2dQ16 T2dQ18 T2dQ02)

    * Directly asks in past 12 months 
    gen self_empl_2ndFup = T2dQ16 == 1 & T2dQ18 != 3
    replace self_empl_2ndFup = . if T2dQ16 == .

    gen wage_worker_2ndFup = T2dQ01 == 1 & T2dQ02 > 2
    replace wage_worker_2ndFup = 0 if self_empl_2ndFup == 1
    replace wage_worker_2ndFup = . if T2dQ01 == .

    gen agri_worker_2ndFup = T2dQ14 == 1 | T2dQ15 == 1 | T2dQ02 <= 2
    replace agri_worker_2ndFup = 0 if self_empl_2ndFup == 1
    replace agri_worker_2ndFup = . if T2dQ01 == .

    gen not_working_2ndFup = T2dQ01 == 2 & T2dQ14 == 2 & T2dQ15 == 2 & T2dQ16 == 2
    replace not_working_2ndFup = . if self_empl_2ndFup == .

    * 18 respondents are associated to 2 households: drop them
    duplicates tag PID, gen(dup)
    drop if dup > 0

    keep PID region_10 district_10 ward_10 self_empl_2ndFup wage_worker_2ndFup agri_worker_2ndFup not_working_2ndFup migration_type_2ndFup
    rename PID pid_10

    isid pid_10
    save "$working_dir/temp/khds_2010", replace

    * Merge all waves
    use "$working_dir/temp/khds_1991", replace

    * Merge m:1 because some observations are not in 2004 wave but are in 2010 wave
    merge m:1 pid_04 using "$working_dir/temp/khds_2004", ///
        nogen assert(1 2 3) keep(1 3)
    merge 1:1 pid_10 using "$working_dir/temp/khds_2010", ///
        nogen assert(1 2 3) keep(1 3)

    foreach fup in 1stFup 2ndFup {
        gen any_migr_`fup' = migration_type_`fup' != 1
        gen village_migr_`fup' = migration_type_`fup' == 2 
        gen withinKagera_migr_`fup' = migration_type_`fup' == 3
        gen regional_migr_`fup' = migration_type_`fup' == 4
        gen international_migr_`fup' = migration_type_`fup' == 5

        foreach var in any_migr_`fup' regional_migr_`fup' withinKagera_migr_`fup' ///
            village_migr_`fup' international_migr_`fup' {
            replace `var' = . if migration_type_`fup' == .
        }
        egen internal_migr_`fup' = rowmax(regional_migr_`fup' withinKagera_migr_`fup' village_migr_`fup')
    }

    gen country = "Tanzania"
    rename pid91_94 person_id

    keep person_id female educyears age_group income occupation country ///
        self_empl_1stFup wage_worker_1stFup agri_worker_1stFup not_working_1stFup ///
        any_migr_1stFup internal_migr_1stFup international_migr_1stFup regional_migr_1stFup ///
        withinKagera_migr_1stFup village_migr_1stFup any_migr_2ndFup internal_migr_2ndFup ///
        international_migr_2ndFup regional_migr_2ndFup withinKagera_migr_2ndFup village_migr_2ndFup ///
        self_empl_2ndFup wage_worker_2ndFup agri_worker_2ndFup not_working_2ndFup

    isid person_id
    save "$working_dir/temp/khds_master", replace
end

program build_income
    use cluster hh id emsaamt emsaunit using ///
        "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7B__IND.dta", clear

    gen salary_week = emsaamt if emsaunit == 4
    * Assume paid 5 days per week
    replace salary_week = emsaamt*5 if emsaunit == 3
    replace salary_week = emsaamt/4 if emsaunit == 5
    replace salary_week = emsaamt/52 if emsaunit == 6

    drop emsaamt emsaunit

    merge 1:1 cluster hh id using "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7C__IND.dta", ///
        keepusing(farmamt procamt herdamt) keep(1 2 3) assert(1 2 3) nogen

    rename (farmamt procamt herdamt) (crop_sales_week processed_sales_week animal_sales_week)

    merge 1:1 cluster hh id using "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7D__IND.dta", ///
        keepusing(se1net se2net) keep(1 2 3) assert(1 2 3) nogen

    rename (se1net se2net) (net_business_inc1 net_business_inc2)

    foreach var in salary_week crop_sales_week processed_sales_week animal_sales_week net_business_inc1 net_business_inc2 {
        replace `var' = 0 if `var' == .
    }
    egen weekly_income = rowtotal(salary_week crop_sales_week processed_sales_week ///
        animal_sales_week net_business_inc1 net_business_inc2)

    keep cluster hh id weekly_income 

    save "$working_dir/temp/khds_income", replace

    * Correct for income from main activity over past year when different
    use cluster hh id mjsame mjweeks em12sala em12salu pr12amt he12amt fa12amt se12net se12netu ///
        using "$raw_data_dir/raw_data/KHDS/TZA_1991_KHDS_v01_M_STATA/khdsdata/HOUSEHOLD/WAVE1/S7F__IND.dta", clear

    gen salary_week = em12sala if em12salu == 4
    * Assume paid 5 days per week
    replace salary_week = em12sala*5 if em12salu == 3
    replace salary_week = em12sala/4 if em12salu == 5
    replace salary_week = em12sala/52 if em12salu == 6

    gen business_inc = se12net if se12netu == 4
    replace business_inc = se12net/4 if se12netu == 5
    replace business_inc = se12net/52 if se12netu == 6

    foreach var in pr12amt he12amt fa12amt {
        gen `var'_week = `var'/mjweeks
    }

    foreach var in salary_week business_inc pr12amt_week he12amt_week fa12amt_week {
        replace `var' = 0 if `var' == .
    }
    egen weekly_income_main_act = rowtotal(salary_week business_inc pr12amt_week he12amt_week fa12amt_week)
    keep if mjsame == 2

    keep cluster hh id weekly_income_main_act
    merge 1:1 cluster hh id using "$working_dir/temp/khds_income", ///
        assert(1 2 3) keep(1 2 3) nogen

    gen income = weekly_income_main_act
    replace income = weekly_income if income == .

    drop weekly_income_main_act weekly_income

    save "$working_dir/temp/khds_income", replace
end

* Execute
main
