clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/descriptive"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    use state lga hhid indiv s1q2 s1q4 using /// 
        "$raw_data_dir/raw_data/LSMS-ISA/Wave 1/Post Planting Wave 1/Household/sect1_plantingw1.dta", clear

    egen person_id = group(hhid indiv)
    tostring person_id, replace

    rename (state lga s1q2 s1q4) (state_10 lga_10 sex age)
    gen female = sex == 2
    
    merge 1:1 hhid indiv using "$raw_data_dir/raw_data/LSMS-ISA/Wave 1/Post Planting Wave 1/Household/sect2_plantingw1.dta", ///
        nogen assert(1 3) keep(3) keepusing(s2q7 s2q8)
    merge 1:1 hhid indiv using "$raw_data_dir/raw_data/LSMS-ISA/Wave 1/Post Planting Wave 1/Household/sect3_plantingw1.dta", ///
        nogen assert(1 2 3) keep(3) keepusing(s3q7 s3q13 s3q14 s3q15 s3q19 s3q20 s3q21a s3q21b)

    gen s6q3a = indiv
    merge 1:m hhid s6q3a using "$raw_data_dir/raw_data/LSMS-ISA/Wave 1/Post Planting Wave 1/Household/sect6_plantingw1.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(s6q24)
    
    bys hhid indiv: egen bus_sales=total(s6q24)
    drop s6q24
    duplicates drop

    * Labor income in last month
    gen laborincome=s3q21a if s3q21b==5
    replace laborincome=s3q21a*8*20 if s3q21b==1
    replace laborincome=s3q21a*20 if s3q21b==2
    replace laborincome=s3q21a*4 if s3q21b==3
    replace laborincome=s3q21a*2 if s3q21b==4
    replace laborincome=s3q21a/3 if s3q21b==6
    replace laborincome=s3q21a/6 if s3q21b==7
    replace laborincome=s3q21a/12 if s3q21b==8

    egen income = rowtotal(laborincome bus_sales)
    gen ln_income = ln(income)

    gen agricultural_activities_10 = (s3q13==2213 | s3q13==3212 | s3q13==3213 | s3q13==6114 | ///
        s3q13==6121 | s3q13==6123 | s3q13==6130 | s3q13==6141 | s3q13==6154 | s3q13==6154 | ///
        s3q13==6210 | s3q13==9211 | s3q13==9212 | s3q13==9213)

    gen not_working_base = 1 if s3q7==2
    replace not_working_base = 0 if s3q7==1

    gen self_empl_base = 1 if s3q15==10 & (s3q14!=1 & agricultural_activities_10!=1)
    replace self_empl_base = 0 if (s3q15!=10 & s3q15!=.) | not_working_base==1 | ///
        (s3q14==1 | agricultural_activities_10==1)

    gen wage_worker_base = 1 if (s3q15!=10 & s3q15!=.) & (s3q20!=2 & s3q20!=3) & ///
        (s3q14!=1 & agricultural_activities_10!=1)
    replace wage_worker_base = 0 if s3q15==10 | not_working_base==1 | ///
        (s3q20==2 | s3q20==3) | (s3q14==1 | agricultural_activities_10==1)
    
    gen agri_worker_base = 1 if agricultural_activities_10==1 | s3q14==1
    replace agri_worker_base = 0 if (agricultural_activities_10!=1 & s3q14!=1) | not_working_base==1

    gen occupation = 0 if not_working_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 2 if wage_worker_base == 1
    replace occupation = 3 if agri_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker" 3 "Agricultural worker"
    label values occupation occupation

    * Years of education
    * Sources:  https://www.nuffic.nl/en/publications/find-a-publication/education-system-nigeria.pdf
    *           https://www.tandfonline.com/doi/abs/10.1080/0022062760080206?journalCode=cjeh20
    *           http://microdata.worldbank.org/index.php/catalog/2163/datafile/F2/V190
    *           http://education.stateuniversity.com/pages/1108/Nigeria-TEACHING-PROFESSION.html
    gen educyears=0 if s2q7==0 | s2q7==1 | s2q7==2
    replace educyears=1 if s2q7==11
    replace educyears=2 if s2q7==12
    replace educyears=3 if s2q7==13
    replace educyears=4 if s2q7==14
    replace educyears=5 if s2q7==15
    replace educyears=6 if s2q7==16 | s2q7==27
    replace educyears=7 if s2q7==21
    replace educyears=8 if s2q7==22
    replace educyears=9 if s2q7==23 | s2q7==33
    replace educyears=10 if s2q7==24
    replace educyears=11 if s2q7==25 | (s2q7==31 & s2q8==7)
    replace educyears=12 if s2q7==26 | s2q7==28 | (s2q7==31 & s2q8==6) | s2q7==32
    replace educyears=15  if s2q7==34 | (s2q7==31 & s2q8==8)
    replace educyears=16  if s2q7==42 | s2q7==41 
    replace educyears=18  if s2q8==11 & educyears==.
    replace educyears=21  if s2q8==12 & educyears==.
    *I do not consider quaranic, quaranic integrated and adult education

    replace educyears=0 if educyears==. & s2q8==1
    replace educyears=6 if educyears==. & s2q8==2
    replace educyears=9 if educyears==. & (s2q8==3 | s2q8==5) 
    replace educyears=11 if educyears==. & s2q8==7
    replace educyears=12 if educyears==. & (s2q8==4 | s2q8==6)
    replace educyears=15 if educyears==. & s2q8==8
    replace educyears=16 if educyears==. & s2q8==9

    drop if age < 18 | age > 65

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    *** Identify movers ***
    * Wave 1: post harvest
    merge 1:1 hhid indiv using "$raw_data_dir/raw_data/LSMS-ISA/Wave 1/Post Harvest Wave 1/Household/sect1_harvestw1.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(s1q33 s1q35 s1q36b s1q36d s1q37)

    * Drop people who died
    drop if s1q33 == 11

    * Set state code to high number if mover to unknown state 
    * (use this so to correctly substitute missings at the end)
    * Set  state code to 500 + country code if mover to foreign country
    gen state_12 = s1q36d if s1q35!=.
    replace state_12 = 500 + s1q37 if s1q37!=.
    replace state_12 = 9999 if s1q35!=. & s1q36d==. & s1q37==.
    
    gen lga_12 = s1q36b if s1q35!=.
    replace lga_12 = 9999 if s1q35!=. & s1q36b==. & s1q37==.

    drop s1q33 s1q35 s1q36b s1q36d s1q37

    * Wave 2: post planting
    merge 1:1 hhid indiv using "$raw_data_dir/raw_data/LSMS-ISA/Wave 2/Post Planting Wave 2/Household/sect1_plantingw2.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(s1q29 s1q31 s1q32b s1q32d s1q33)

    drop if s1q29 == 11

    replace state_12 = s1q32d if s1q31!=.
    replace state_12 = 500 + s1q33 if s1q33!=.
    replace state_12 = 9999 if s1q31!=. & s1q32d==. & s1q33==.

    replace lga_12 = s1q32b if s1q31!=.
    replace lga_12 = 9999 if s1q31!=. & s1q32b==. & s1q33==.

    drop s1q29 s1q31 s1q32b s1q32d s1q33

    * Wave 2: post harvest
    merge 1:1 hhid indiv using "$raw_data_dir/raw_data/LSMS-ISA/Wave 2/Post Harvest Wave 2/Household/sect1_harvestw2.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(state lga s1q28 s1q30 s1q31b s1q31d s1q32)

    drop if s1q28 == 11

    replace state_12 = s1q31d if s1q30!=.
    replace state_12 = 500 + s1q32 if s1q32!=.
    replace state_12 = 9999 if s1q30!=. & s1q31d==. & s1q32==.

    replace lga_12 = s1q31b if s1q30!=.
    replace lga_12 = 9999 if s1q30!=. & s1q31b==. & s1q32==.

    drop s1q28 s1q30 s1q31b s1q31d s1q32

    * For non movers, get location of household
    replace state_12 = state if state_12==.
    replace state_12 = . if state_12==9999
    
    replace lga_12 = lga if lga_12==.
    replace lga_12 = . if lga_12==9999

    drop state lga

    save "$working_dir/temp/lsms_isa_1stFup", replace

    * Wave 3: post planting
    * No country recorded for wave 3
    merge 1:1 hhid indiv using "$raw_data_dir/raw_data/LSMS-ISA/Wave 3/sect1_plantingw3.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(s1q29 s1q31 s1q32b s1q32d)

    drop if s1q29 == 11

    gen state_15 = state_12
    replace state_15 = s1q32d if s1q31==1
    replace state_15 = 500 if s1q31==2
    replace state_15 = 9999 if s1q31==1 & s1q32d==.

    gen lga_15 = lga_12
    replace lga_15 = s1q32b if s1q31==1
    replace lga_15 = 9999 if s1q31==1 & s1q32b==.

    drop s1q29 s1q31 s1q32b s1q32d

    * Wave 3: post harvest
    merge 1:1 hhid indiv using "$raw_data_dir/raw_data/LSMS-ISA/Wave 3/sect1_harvestw3.dta", ///
        nogen assert(1 2 3) keep(1 3) keepusing(state lga s1q28 s1q30 s1q31b s1q31d)

    drop if s1q28 == 14

    replace state_15 = s1q31d if s1q30==1
    replace state_15 = 500 if s1q30==2
    replace state_15 = 9999 if s1q30==1 & s1q31d==.

    replace lga_15 = s1q31b if s1q30==1
    replace lga_15 = 9999 if s1q30==1 & s1q31b==.

    * For non movers, get location of household
    replace state_15 = state if state_15==.
    replace state_15 = . if state_15==9999
    
    replace lga_15 = lga if lga_15==.
    replace lga_15 = . if lga_15==9999

    save "$working_dir/temp/lsms_isa_2ndFup", replace

    * Create migration variables
    foreach endyear in "12" "15" {

        if "`endyear'" == "12" local fup "1stFup"
        else if "`endyear'" == "15" local fup "2ndFup"

        use "$working_dir/temp/lsms_isa_`fup'", clear

        gen international_migr_`fup'=1 if state_`endyear'>=500 & state_`endyear'!=.
        replace international_migr_`fup'=0 if state_`endyear'<500 & state_`endyear'!=.

        gen state_migr_`fup'=1 if state_`endyear'!=state_10 & state_`endyear'<500 & state_10!=. & state_`endyear'!=.
        replace state_migr_`fup'=0 if state_`endyear'==state_10 & state_`endyear'<500 & state_10!=. & state_`endyear'!=.

        gen lga_migr_`fup'=1 if lga_`endyear'!=lga_10 & lga_`endyear'!=. & lga_10!=. & state_migr_`fup'!=1
        replace lga_migr_`fup'=0 if lga_`endyear'==lga_10 & lga_`endyear'!=. & lga_10!=.

        egen any_migr_`fup' = rowmax(international_migr_`fup' state_migr_`fup' lga_migr_`fup')
        egen internal_migr_`fup' = rowmax(state_migr_`fup' lga_migr_`fup')
        
        gen country = "Nigeria"

        keep person_id female educyears age_group income occupation country ///
            any_migr_`fup' internal_migr_`fup' international_migr_`fup' ///
            state_migr_`fup' lga_migr_`fup'
        
        isid person_id
        save "$working_dir/temp/lsms_isa_`fup'", replace
    }
end

* Execute
main
