clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/descriptive"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    * Round 1
    use folio edad edo mpio loc using ///
        "$raw_data_dir/raw_data/MxFLS/hh02dta_all/hh02dta_bc/c_portad.dta" if folio!=., clear
     
    rename (edad edo mpio loc) (age state_02 mpio_02 loc_02)
    
    duplicates drop

    merge 1:m folio using "$raw_data_dir/raw_data/MxFLS/hh02dta_all/hh02dta_b3a/iiia_tb.dta", ///
        nogen assert(1 2 3) keep(3)
    merge 1:1 folio ls using "$raw_data_dir/raw_data/MxFLS/hh02dta_all/hh02dta_bc/c_ls.dta", ///
        nogen assert(1 2 3) keep(3) keepusing(ls04 ls14 ls15_1)

    gen female = ls04 == 3

    gen not_working_base = 1 if tb02_1!=1 & tb32p==. & tb24_26p_cmo==.
    replace not_working_base = 0 if tb02_1==1 | tb32p!=. | tb24_26p_cmo!=.

    gen self_empl_base = 1 if (tb32p==5 | tb32p==6) & tb24_26p_cmo!=41
    replace self_empl_base = 0 if (tb32p!=5 & tb32p!=6) | tb24_26p_cmo==41

    gen wage_worker_base = 1 if tb32p==3 & tb24_26p_cmo!=41
    replace wage_worker_base = 0 if (tb32p!=3 & tb32p!=7) | tb24_26p_cmo==41

    gen agri_worker_base = 1 if tb32p==1 | tb32p==4 | tb24_26p_cmo==41
    replace agri_worker_base = 0 if tb32p!=1 & tb32p!=4 & tb24_26p_cmo!=41

    gen occupation = 0 if not_working_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 2 if wage_worker_base == 1
    replace occupation = 3 if agri_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker" 3 "Agricultural worker"
    label values occupation occupation

    egen wages = rowtotal(tb36aa_2 - tb36am_21)
    gen profit = tb38p2_2
    replace profit = tb38p1_2 if profit == . & tb38p1_2 != .

    egen income = rowtotal(wages profit)
    gen ln_income = ln(income)

    * Compute years of education
    * Sources:   https://en.wikipedia.org/wiki/Education_in_Mexico
    *            http://www.oas.org/udse/gestion/ges_rela20a.html

    gen educyears=0 if ls14==1 | ls14==2
    *Elementary school
    replace educyears=ls15_1 if ls14==3 & ls15_1!=8
    *Secondary school
    replace educyears=6+ls15_1 if (ls14==4 | ls14==5) & ls15_1!=8
    *High School
    replace educyears=9+ls15_1 if (ls14==6 | ls14==7) & ls15_1!=8
    *Tertiary
    replace educyears=12+ls15_1 if (ls14==8 | ls14==9) & ls15_1!=8
    replace educyears=16+ls15_1 if (ls14==10) & ls15_1!=8

    *Given that for the majority of individuals with tertiary education educyears is missing, I code educyears of those with college education to 16 and of those with graduate education to 18
    replace educyears=16 if ls14==9 & educyears==.
    replace educyears=18 if ls14==10 & educyears==.

    tostring folio, gen(folio_02) format("%08.0f")
    tostring ls, gen(ls_02) format("%02.0f")
    gen pid_link = folio_02 + ls_02

    keep pid_link folio_02 ls_02 age state_02 mpio_02 loc_02 not_working_base ///
        self_empl_base wage_worker_base agri_worker_base ln_income income educyears female occupation
    
    drop if age < 18 | age > 65

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    save "$working_dir/temp/mxfls_base", replace

    ******************************************************
    * Create migration between wave 1 and wave 2

    use "$working_dir/temp/mxfls_base", clear
    merge 1:m pid_link using "$raw_data_dir/raw_data/MxFLS/hh05dta_all/hh05dta_bc/c_ls.dta", ///
        nogen assert(1 2 3) keep(3) keepusing(folio ls01a ls19a_21 ls19e_1)
    
    * Drop if dead
    drop if ls01a == 0

    gen locality_migr_1stFup = ls19e_1 == 2 & (ls19a_21 >= 2001 & ls19a_21 <= 2006)
    replace locality_migr_1stFup = . if ls19e_1 == 8

    gen municipio_migr_1stFup = ls19e_1 == 3 & (ls19a_21 >= 2001 & ls19a_21 <= 2006)
    replace municipio_migr_1stFup = . if ls19e_1 == 8

    gen state_migr_1stFup = ls19e_1 == 4 & (ls19a_21 >= 2001 & ls19a_21 <= 2006)
    replace state_migr_1stFup = . if ls19e_1 == 8

    gen international_migr_1stFup = ls19e_1 == 5 & (ls19a_21 >= 2001 & ls19a_21 <= 2006)
    replace international_migr_1stFup = . if ls19e_1 == 8

    merge m:1 folio using "$raw_data_dir/raw_data/MxFLS/hh05dta_all/hh05dta_bc/c_portad.dta", ///
        nogen assert(2 3) keep(3) keepusing(ent mpio loc)

    rename (ent mpio loc) (state_05 mpio_05 loc_05)
    foreach year in "02" "05" {
        geographic_vars, year(`year')
    }

    replace state_migr_1stFup = 1 if state_str_05 != state_str_02 & state_str_05 != "" & state_str_02 != ""
    replace municipio_migr_1stFup = 1 if mpio_str_05 != mpio_str_02 & mpio_str_05 != "" & mpio_str_02 != "" & state_migr_1stFup!=1
    replace locality_migr_1stFup = 1 if loc_str_05 != loc_str_02 & loc_str_05 != "" & loc_str_02 != "" & state_migr_1stFup!=1 & municipio_migr_1stFup!=1

    egen internal_migr_1stFup = rowmax(locality_migr_1stFup municipio_migr_1stFup state_migr_1stFup)

    drop folio ls01a ls19a_21 ls19e_1
    save "$working_dir/temp/mxfls_1stFup", replace

    *** NOTE ***
    * Add information from migration module
    * In this module we cannot distinguish between different types of migration

    use pid_link mg12_21 mg14_1 mg17e_1 mg17e_2 mg17l_1 mg17m_1 mg17p_2 using ///
        "$raw_data_dir/raw_data/MxFLS/hh05dta_all/hh05dta_b3a/iiia_mg1.dta", clear
        
    keep if mg12_21 >= 2001 & mg12_21 != .
    keep if mg14_1 == 2

    merge 1:1 pid_link using "$raw_data_dir/raw_data/MxFLS/hh05dta_all/hh05dta_b3a/iiia_mg.dta", ///
        nogen assert(2 3) keep(3) keepusing(mg08a_1)
    merge 1:1 pid_link using "$working_dir/temp/mxfls_1stFup", ///
        nogen assert(1 2 3) keep(2 3)
    merge 1:1 pid_link using "$raw_data_dir/raw_data/MxFLS/migus/migus.dta", ///
        nogen assert(2 3) keep(3)

    replace international_migr_1stFup = 1 if migus == 1 | mg17p_2 != ""
    
    replace internal_migr_1stFup = 1 if mg08a_1 == 1 & mg17p_2 == ""
    replace internal_migr_1stFup = 0 if international_migr_1stFup == 1 

    egen any_migr_1stFup = rowmax(international_migr_1stFup internal_migr_1stFup)

    drop mg08a_1 mg12_21 mg14_1 mg17e_1 mg17e_2 mg17l_1 mg17m_1 mg17p_2
    save "$working_dir/temp/mxfls_1stFup", replace

    * Wave 3
    *** NOTE ***
    * No information on migrants to US
    use pid_link folio ls01a ls19a_21 ls19e_1 panel using ///
        "$raw_data_dir/raw_data/MxFLS/hh09dta_all/hh09dta_bc/c_ls.dta" if panel!=., clear
    gen hhld_formed = substr(pid_link,7,2)
    keep if hhld_formed == "AP"

    rename pid_link origpid_link
    gen pid_link = substr(origpid_link,1,6) + substr(origpid_link,9,4)

    merge 1:1 pid_link using "$working_dir/temp/mxfls_1stFup", ///
        nogen assert(1 2 3) keep(3)

    drop if ls01a == 0

    gen state_migr_2ndFup = state_migr_1stFup
    replace state_migr_2ndFup = 0 if ls01a == 6
    replace state_migr_2ndFup = 1 if ls19e_1 == 4 & (ls19a_21 >= 2005 & ls19a_21 <= 2010)
    replace state_migr_2ndFup = . if ls19e_1 == 8

    gen municipio_migr_2ndFup = municipio_migr_1stFup
    replace municipio_migr_2ndFup = 0 if ls01a == 6
    replace municipio_migr_2ndFup = 1 if ls19e_1 == 3 & (ls19a_21 >= 2005 & ls19a_21 <= 2010)
    replace municipio_migr_2ndFup = . if ls19e_1 == 8

    gen locality_migr_2ndFup = locality_migr_1stFup
    replace locality_migr_2ndFup = 0 if ls01a == 6
    replace locality_migr_2ndFup = 1 if ls19e_1 == 2 & (ls19a_21 >= 2005 & ls19a_21 <= 2010)
    replace locality_migr_2ndFup = . if ls19e_1 == 8

    gen international_migr_2ndFup = international_migr_1stFup
    replace international_migr_2ndFup = 0 if ls01a == 6
    replace international_migr_2ndFup = 1 if ls19e_1 == 5 & (ls19a_21 >= 2005 & ls19a_21 <= 2010)
    replace international_migr_2ndFup = . if ls19e_1 == 8

    merge m:1 folio using "$raw_data_dir/raw_data/MxFLS/hh09dta_all/hh09dta_bc/c_portad.dta", ///
        nogen assert(2 3) keep(3) keepusing(ent mpio loc)

    rename (ent mpio loc) (state_09 mpio_09 loc_09)
    geographic_vars, year("09")
    
    replace state_migr_2ndFup = 1 if state_09 != state_02 & state_09 != . & state_02 != .
    replace municipio_migr_2ndFup = 1 if mpio_09 != mpio_02 & mpio_09 != . & mpio_02 != . & state_migr_2ndFup!=1
    replace locality_migr_2ndFup = 1 if loc_09 != loc_02 & loc_09 != . & loc_02 != . & state_migr_2ndFup!=1 & municipio_migr_2ndFup!=1

    replace municipio_migr_2ndFup = 0 if state_migr_2ndFup == 1
    replace locality_migr_2ndFup = 0 if state_migr_2ndFup == 1 | municipio_migr_2ndFup == 1

    egen internal_migr_2ndFup = rowmax(locality_migr_2ndFup municipio_migr_2ndFup state_migr_2ndFup)

    save "$working_dir/temp/mxfls_2ndFup", replace

    use pid_link mg12_21 mg14_1 mg17e_1 mg17e_2 mg17l_1 mg17m_1 mg17p_2 using ///
        "$raw_data_dir/raw_data/MxFLS/hh09dta_all/hh09dta_b3a/iiia_mg1.dta", clear
        
    keep if mg12_21 >= 2005 & mg12_21 != .
    keep if mg14_1 == 2
    duplicates drop pid_link, force

    merge 1:1 pid_link using "$raw_data_dir/raw_data/MxFLS/hh09dta_all/hh09dta_b3a/iiia_mg.dta", ///
        nogen keep(3) keepusing(mg08a_1)
    
    rename pid_link origpid_link
    merge 1:1 origpid_link using "$working_dir/temp/mxfls_2ndFup", ///
        nogen assert(1 2 3) keep(2 3)

    replace international_migr_2ndFup = 1 if mg17p_2 != ""
    
    replace internal_migr_2ndFup = 1 if mg08a_1 == 1 & mg17p_2 == ""
    replace internal_migr_2ndFup = 0 if international_migr_2ndFup == 1
    
    foreach var in internal_migr international_migr {
        replace `var'_2ndFup = . if `var'_1stFup == 1 & mg08a_1 == 1
    }

    egen any_migr_2ndFup = rowmax(internal_migr_2ndFup international_migr_2ndFup)

    save "$working_dir/temp/mxfls_2ndFup", replace

    * Save the two waves separately
    foreach fup in 1stFup 2ndFup {
        use "$working_dir/temp/mxfls_`fup'", clear
        rename pid_link person_id
        gen country = "Mexico"

        keep person_id female educyears age_group income occupation country any_migr_`fup' ///
            internal_migr_`fup' international_migr_`fup' state_migr_`fup' ///
            municipio_migr_`fup' locality_migr_`fup'

        isid person_id
        save "$working_dir/temp/mxfls_`fup'", replace
    }
end

program geographic_vars
    syntax, year(str)

    gen state_str_`year' = string(state_`year') if state_`year' != .
    gen mpio_str_`year' = string(state_`year') + string(mpio_`year') if ///
        state_`year' != . & mpio_`year' != .
    gen loc_str_`year' = string(state_`year') + string(mpio_`year') + string(loc_`year') if ///
        state_`year' != . & mpio_`year' != . & loc_`year' != .
end

* Execute
main
