clear all
set more off

global raw_data_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/analysis/descriptive"
global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    * Import data and labels
    do "$raw_data_dir/raw_data/PSID/J262450.do"
    do "$raw_data_dir/raw_data/PSID/J262450_formats.do"

    rename (ER33603 ER17013 ER17015 ER31997 ER31996 ER33950 ER34650 ER32000 ER20457 ER20458 ///
        ER17221 ER17791 ER36134 ER36392 ER66198 ER66473 ER18484) ///
        (relation_to_head age_head age_wife cluster stratum longit_weight_2007 longit_weight_2017 sex ///
        educyears_head educyears_wife employment_2001_head employment_2001_wife employment_2007_head ///
        employment_2007_wife employment_2017_head employment_2017_wife farmer_head)

    gen female = sex == 2

    rename (ER20420 ER20422 ER20443 ER20444 ER20447 ER18929) ///
        (farm_income_head business_income_head labor_income_head ///
        business_income_wife labor_income_wife wife_income_work)

    gen farm_income_wife = 0
    replace farm_income_wife = farm_income_head/2 if wife_income_work == 4
    replace farm_income_head = farm_income_head/2 if wife_income_work == 4

    foreach type in head wife {
        egen income_`type' = rowtotal(farm_income_`type' business_income_`type' labor_income_`type')
    }

    * Keep only HoH and wife
    keep if relation_to_head == 10 | relation_to_head == 20 | relation_to_head == 22

    foreach var in age educyears employment_2001 employment_2007 employment_2017 income {
        gen `var' = `var'_head if relation_to_head == 10
        replace `var' = `var'_wife if relation_to_head == 20 | relation_to_head == 22
    }
    replace educyears = . if educyears == 99

    gen ln_income = ln(income)

    drop if age < 18 | age > 65

    gen age_group = 1 if age < 25
    replace age_group = 2 if age >= 25 & age <= 34
    replace age_group = 3 if age >= 35 & age <= 44
    replace age_group = 4 if age >= 45 & age <= 54
    replace age_group = 5 if age >= 55

    label define age_group 1 "18 to 24" 2 "25 to 34" 3 "35 to 44" 4 "45 to 54" 5 "55 to 65"
    label values age_group age_group

    rename (ER17005 ER36004 ER66004 ER20376 ER41032 ER71530) ///
        (state_2001 state_2007 state_2017 region_2001 region_2007 region_2017)

    * Drop if state at baseline is not reported
    drop if state_2001 == 99

    * Compute migration variables
    foreach endyear in 2007 2017 {
        if "`endyear'" == "2007" local fup "1stFup"
        else if "`endyear'" == "2017" local fup "2ndFup"

        gen internal_migr_`fup' = state_2001 != state_`endyear'
        replace internal_migr_`fup' = . if state_`endyear' == 99 | state_`endyear' == .
        replace internal_migr_`fup' = 0 if (state_2001 == 0 & state_`endyear' != 0) ///
            | (state_2001 != 0 & state_`endyear' == 0)

        gen international_migr_`fup' = (state_2001 == 0 & state_`endyear' != 0) ///
            | (state_2001 != 0 & state_`endyear' == 0)
        replace international_migr_`fup' = . if state_`endyear' == 99 | state_`endyear' == .

        egen any_migr_`fup' = rowmax(internal_migr_`fup' international_migr_`fup')
    }

    * Compute employment variables
    foreach year in 2001 2007 2017 {
        if "`year'" == "2001" local fup "base"
        else if "`year'" == "2007" local fup "1stFup"
        else if "`year'" == "2017" local fup "2ndFup"

        gen self_empl_`fup' = employment_`year' == 3
        gen wage_worker_`fup' = employment_`year' == 1
        gen not_working_`fup' = employment_`year' == 0

        foreach var in self_empl wage_worker not_working {
            replace `var'_`fup' = . if employment_`year' == 8 | employment_`year' == 9
        }
    }

    gen occupation = 0 if not_working_base == 1
    replace occupation = 1 if self_empl_base == 1
    replace occupation = 2 if wage_worker_base == 1

    label define occupation 0 "Not working" 1 "Self-employed" 2 "Wage worker"
    label values occupation occupation

    egen person_id = group(ER30001 ER30002)
    tostring person_id, replace

    gen country = "USA"

    keep person_id female educyears age_group income occupation country ///
        any_migr_1stFup internal_migr_1stFup international_migr_1stFup ///
        any_migr_2ndFup internal_migr_2ndFup international_migr_2ndFup ///
        self_empl_1stFup wage_worker_1stFup not_working_1stFup ///
        self_empl_2ndFup wage_worker_2ndFup not_working_2ndFup

    isid person_id
    save "$working_dir/temp/psid_master", replace
end

* Execute
main
