clear all
set more off
grstyle init
grstyle color background white

global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    preclean
    build_figures
    build_appendix_figure
end

program preclean
    use "$working_dir/derived_data/master_panel_descriptive", clear

    * Country names and ordering for figures
    gen country_followUP = "Indonesia 2000-2007/08" if country=="Indonesia" & followUp==1
    replace country_followUP = "Indonesia 2000-2014/15" if country=="Indonesia" & followUp==2
    replace country_followUP = "Mexico 2002-05/06" if country=="Mexico" & followUp==1
    replace country_followUP = "Mexico 2002-09/12" if country=="Mexico" & followUp==2
    replace country_followUP = "Nigeria 2010/11-12/13" if country=="Nigeria" & followUp==1
    replace country_followUP = "Nigeria 2010/11-15/16" if country=="Nigeria" & followUp==2
    replace country_followUP = "India 2005-2011" if country=="India" & followUp==1
    replace country_followUP = "Tanzania 1991-2004" if country=="Tanzania" & followUp==1
    replace country_followUP = "Tanzania 1991-2010" if country=="Tanzania" & followUp==2
    replace country_followUP = "Egypt 1998-2006" if country=="Egypt" & followUp==1
    replace country_followUP = "Egypt 1998-2012" if country=="Egypt" & followUp==2
    replace country_followUP = "China 2010-2016" if country=="China" & followUp==1
    replace country_followUP = "US 2001-2007" if country=="USA" & followUp==1
    replace country_followUP = "US 2001-2017" if country=="USA" & followUp==2

    gen order_country = 5 if country_followUP=="Indonesia 2000-2007/08"
    replace order_country = 6 if country_followUP=="Indonesia 2000-2014/15"
    replace order_country = 7 if country_followUP=="Mexico 2002-05/06" 
    replace order_country = 8 if country_followUP=="Mexico 2002-09/12"
    replace order_country = 9 if country_followUP=="Nigeria 2010/11-12/13"
    replace order_country = 10 if country_followUP=="Nigeria 2010/11-15/16"
    replace order_country = 4 if country_followUP=="India 2005-2011"
    replace order_country = 11 if country_followUP=="Tanzania 1991-2004"
    replace order_country = 12 if country_followUP=="Tanzania 1991-2010" 
    replace order_country = 2 if country_followUP=="Egypt 1998-2006"
    replace order_country = 3 if country_followUP=="Egypt 1998-2012"
    replace order_country = 1 if country_followUP=="China 2010-2016"
    replace order_country = 13 if country_followUP=="US 2001-2007"
    replace order_country = 14 if country_followUP=="US 2001-2017"

    save "$working_dir/temp/master_panel_descriptive_fig", replace
end

program build_figures
    * Build migration by gender plot for selected surveys
    migration_by_gender_age, fups(1stFup) survey(CFPS) country(China)
    migration_by_gender_age, fups(1stFup) survey(IFLS) country(Indonesia)
    migration_by_gender_age, fups(1stFup) survey(IHDS) country(India)
    migration_by_gender_age, fups(1stFup) survey(LSMS) country(Nigeria)
    migration_by_gender_age, fups(1stFup) survey(MXFLS) country(Mexico)
    migration_by_gender_age, fups(1stFup) survey(PSID) country(USA)

    use "$working_dir/temp/master_panel_descriptive_fig", clear
    
    * Drop agricultural workers
    drop if occupation==3 | occupation==.

    gen order_occ = 1 if occupation==1
    replace order_occ = 2 if occupation==2
    replace order_occ = 3 if occupation==0
    
    * Count number of observations, excluding individuals with missing occupation
    distinct person_id if any_migr!=.

    * Migration rates
    graph bar (mean) any_migr, over(occupation, lab(nolab) sort(order_occ) gap(*.1)) ///
        over(country_followUP, sort(order_country) lab(angle(45) labsize(small)) gap(*2)) ///
        asyvars bar(1, bfc(gs5) blc(black)) bar(2, bfc(gs9) blc(black)) bar(3, bc(gs15) blc(black)) ///
        ytitle("") legend(size(small) rows(1) order(2 3 1)) nofill

    graph export "$working_dir/output/descriptive/master/any_migr.png", replace

    preserve
    drop if country == "China" | country == "Egypt"
    distinct person_id if internal_migr!=.

    graph bar (mean) internal_migr, over(occupation, lab(nolab) sort(order_occ) gap(*.1)) ///
        over(country_followUP, sort(order_country) lab(angle(45) labsize(small)) gap(*2)) ///
        asyvars bar(1, bfc(gs5) blc(black)) bar(2, bfc(gs9) blc(black)) bar(3, bc(gs15) blc(black)) ///
        ytitle("") legend(size(small) rows(1) order(2 3 1)) nofill

    graph export "$working_dir/output/descriptive/master/internal_migr.png", replace

    drop if country == "Tanzania"
    distinct person_id if international_migr!=. 

    graph bar (mean) international_migr, over(occupation, lab(nolab) sort(order_occ) gap(*.1)) ///
        over(country_followUP, sort(order_country) lab(angle(45) labsize(small)) gap(*2)) ///
        asyvars bar(1, bfc(gs5) blc(black)) bar(2, bfc(gs9) blc(black)) bar(3, bc(gs15) blc(black)) ///
        ytitle("") legend(size(small) rows(1) order(2 3 1)) nofill

    graph export "$working_dir/output/descriptive/master/international_migr.png", replace
    restore

    * Proportion self-employed at destination
    drop if country=="Mexico" | country=="Nigeria"
    keep if any_migr==1
    distinct person_id if self_empl_dest!=.

    qui sum self_empl_dest if occupation == 1
    local avg_self_empl = `r(mean)'

    graph bar (mean) self_empl_dest, over(occupation, lab(nolab) sort(order_occ) gap(*.1)) ///
        over(country_followUP, sort(order_country) lab(angle(45) labsize(small)) gap(*2)) ///
        asyvars bar(1, bfc(gs5) blc(black)) bar(2, bfc(gs9) blc(black)) bar(3, bc(gs15) blc(black)) ///
        ytitle("") legend(size(small) rows(1) order(2 3 1)) nofill yline(`avg_self_empl', lp(dash) lc(gs9))

    graph export "$working_dir/output/descriptive/master/self_employment_at_destination.png", replace

    * Proportion wage workers at destination
    qui sum wage_worker_dest if occupation == 1
    local avg_wage_worker = `r(mean)'

    graph bar (mean) wage_worker_dest, over(occupation, lab(nolab) sort(order_occ) gap(*.1)) ///
        over(country_followUP, sort(order_country) lab(angle(45) labsize(small)) gap(*2)) ///
        asyvars bar(1, bfc(gs5) blc(black)) bar(2, bfc(gs9) blc(black)) bar(3, bc(gs15) blc(black)) ///
        ytitle("") legend(size(small) rows(1) order(2 3 1)) nofill yline(`avg_wage_worker', lp(dash) lc(gs9))

    graph export "$working_dir/output/descriptive/master/wage_worker_at_destination.png", replace

    * Proportion not working at destination
    qui sum not_working_dest if occupation == 1
    local avg_not_working = `r(mean)'

    graph bar (mean) not_working_dest, over(occupation, lab(nolab) sort(order_occ) gap(*.1)) ///
        over(country_followUP, sort(order_country) lab(angle(45) labsize(small)) gap(*2)) ///
        asyvars bar(1, bfc(gs5) blc(black)) bar(2, bfc(gs9) blc(black)) bar(3, bc(gs15) blc(black)) ///
        ytitle("") legend(size(small) rows(1) order(2 3 1)) nofill yline(`avg_not_working', lp(dash) lc(gs9))

    graph export "$working_dir/output/descriptive/master/not_working_at_destination.png", replace

    * Averages not working at destination
    bys occupation: sum not_working_dest

    * Check wage workers at origin and destination
    sum wage_worker_dest if occupation == 2
end

program build_appendix_figure
    use "$working_dir/temp/master_panel_descriptive_fig" if country!="USA", clear

    * Keep agriculture and self-employed
    keep if occupation==3 | occupation==1

    gen order_occ = 1 if occupation==1
    replace order_occ = 2 if occupation==3

    distinct person_id if any_migr!=.

    * Migration rates
    graph bar (mean) any_migr, over(occupation, lab(nolab) sort(order_occ) gap(*.1)) ///
        over(country_followUP, sort(order_country) lab(angle(45) labsize(small)) gap(*2)) ///
        asyvars bar(1, bfc(gs12) blc(black)) bar(2, bfc(gs5) blc(black)) ///
        ytitle("") legend(size(small) rows(1) order(1 2)) nofill

    graph export "$working_dir/output/descriptive/master/any_migr_agri_workers.png", replace

    * Correlation self-employment origin vs destination
    use "$working_dir/temp/master_panel_descriptive_fig" if ///
        any_migr==1 & country!="Mexico" & country!="Nigeria", clear

    * Drop agricultural workers and undetermined occupation
    * Need to compute origin and destination separately
    preserve
        drop if occupation == 3 | occupation == .

        gen self_empl_origin = occupation == 1
        collapse (mean) self_empl_origin, by(country_followUP)

        save "$working_dir/temp/self_empl_origin", replace
    restore

    drop if agri_worker_dest == 1 | self_empl_dest == .
    collapse (mean) self_empl_dest, by(country_followUP)

    merge 1:1 country_followUP using "$working_dir/temp/self_empl_origin", ///
        nogen assert(3) keep(3)

    replace self_empl_origin = self_empl_origin*100
    replace self_empl_dest = self_empl_dest*100

    gen pos = 3
    replace pos = 9 if country_followUP=="Tanzania 1991-2004" | country_followUP=="Tanzania 1991-2010" ///
        | country_followUP=="Egypt 1998-2006"
    replace pos = 11 if country_followUP=="Egypt 1998-2012"

    scatter self_empl_dest self_empl_origin, mlabel(country_followUP) ///
        mlabv(pos) mlabsize(vsmall) mlabc(gs5) mc(gs5) xlabel(0(5)30) xsc(r(0 30)) ///
        ytitle("Self-employment rate at destination (%)") ///
        xtitle("Self-employment rate at origin (%)")

    graph export "$working_dir/output/descriptive/master/corr_self_empl_rates.png", replace

    use "$working_dir/temp/master_panel_descriptive_fig" if ///
        any_migr==1 & country!="Mexico" & country!="Nigeria", clear

    keep if occupation == 1 & self_empl_dest != .

    gen maintain_self_empl = self_empl_dest == 1
    collapse (mean) maintain_self_empl, by(country_followUP)

    merge 1:1 country_followUP using "$working_dir/temp/self_empl_origin", ///
        nogen assert(3) keep(3)

    replace self_empl_origin = self_empl_origin*100
    replace maintain_self_empl = maintain_self_empl*100

    gen pos = 3
    replace pos = 9 if country_followUP=="Tanzania 1991-2004" | country_followUP=="Tanzania 1991-2010"

    corr maintain_self_empl self_empl_origin

    scatter maintain_self_empl self_empl_origin, mlabel(country_followUP) ///
        mlabv(pos) mlabsize(vsmall) mlabc(gs5) mc(gs5) xlabel(0(5)30) xsc(r(0 30)) ///
        ytitle("Proportion of the self-employed at origin" "who are self-employed at destination (%)") ///
        xtitle("Self-employment rate at origin (%)")

    graph export "$working_dir/output/descriptive/master/corr_maintain_self_empl.png", replace
end

program migration_by_gender_age
    syntax, fups(str) survey(str) country(str)

    foreach fup in `fups' {
        use "$working_dir/temp/master_panel_descriptive_fig", clear
        keep if country=="`country'"

        collapse (mean) any_migr_`fup', by(age_group female occupation)

        foreach female in 0 1 {
            graph twoway (connected any_migr_`fup' age_group if occupation==1 & female==`female', lc(gs6) mc(gs6)) ///
                (connected any_migr_`fup' age_group if occupation==2 & female==`female', lp(dash) lc(gs6) mc(gs6)), ///
                xlabel(, valuelabel labsize(*0.9)) ylabel(0(.1).4, labsize(*0.9)) legend(label(1 "Self-employed") ///
                label(2 "Wage worker")) ytitle("") xtitle("Age group")

            graph export "$working_dir/output/descriptive/`survey'_migration_`fup'_by_age_female`female'.png", replace
        }
    }
end

* Execute
main
