clear all
set more off

global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"
adopath + "$working_dir/lib/"

program main
    separate_regs
    stacked_reg
    stacked_reg_withNotEmpl
end

program separate_regs
    local rtitles = `""Self-employed" \ "" \ "Aged 25 to 34" \ "" \ "Aged 35 to 44" \ "" \ "Aged 45 to 54" \ "" \ "' + ///
        `""Aged 55 to 65" \ "" \ "Years of education" \ "" \ "Female" \ "" \ "arcsinh(income)" \ "" \ "Wage worker mean" \ "Sample size""'

    use "$working_dir/derived_data/master_panel_descriptive", clear

    keep if occupation==1 | occupation==2
    gen self_empl_base = occupation==1
    gen wage_worker_base = occupation==2

    egen country_nbr = group(country)
    gen ihs_income = ln(income + sqrt(income^2 + 1))

    foreach fup in 1stFup 2ndFup {
        *** Internal vs international migration ***
        build_separate_table, fup(`fup') outcomes("any_migr internal_migr international_migr")

        local ctitles = `""", "Any migration", "Internal migration", "International migration", "' + ///
            `""Any migration", "Internal migration", "International migration""'
        
        frmttable using "$working_dir/output/descriptive/master/descriptive_reg_`fup'_table", ///
            statmat(table) sdec(3) annotate(table_stars) asymbol(*,**,***) ///
            tex replace fragment ctitles(`ctitles') rtitles(`rtitles')

        *** Various levels of internal migration ***
        build_separate_table, fup(`fup') outcomes("level3_migr level2_migr level1_migr")

        local ctitles = `""", "Level 3 migration", "Level 2 migration", "Level 1 migration", "' + ///
            `""Level 3 migration", "Level 2 migration", "Level 1 migration""'
        
        frmttable using "$working_dir/output/descriptive/master/descriptive_reg_`fup'_migrLevels_table", ///
            statmat(table) sdec(3) annotate(table_stars) asymbol(*,**,***) ///
            tex replace fragment ctitles(`ctitles') rtitles(`rtitles')
    }
end

program stacked_reg
    local rtitles = `""Self-employed" \ "" \ "Aged 25 to 34" \ "" \ "Aged 35 to 44" \ "" \ "Aged 45 to 54" \ "" \ "' + ///
        `""Aged 55 to 65" \ "" \ "Years of education" \ "" \ "Female" \ "" \ "arcsinh(income)" \ "" \ "Wage worker mean" \ "Sample size""'

    use "$working_dir/derived_data/master_panel_descriptive", clear

    keep if occupation==1 | occupation==2
    gen self_empl_base = occupation==1
    gen wage_worker_base = occupation==2

    egen country_followUP = group(country followUp)
    gen ihs_income = ln(income + sqrt(income^2 + 1))

    *** Internal vs international migration ***
    build_stacked_table, outcomes("any_migr internal_migr international_migr")

    local ctitles = `""", "Any migration", "Internal migration", "International migration", "' + ///
        `""Any migration", "Internal migration", "International migration""'

    frmttable using "$working_dir/output/descriptive/master/descriptive_reg_stacked_table", ///
        statmat(table) sdec(3) annotate(table_stars) asymbol(*,**,***) ///
        tex replace fragment ctitles(`ctitles') rtitles(`rtitles')

    *** Various levels of internal migration ***
    build_stacked_table, outcomes("level3_migr level2_migr level1_migr")

    local ctitles = `""", "Level 3 migration", "Level 2 migration", "Level 1 migration", "' + ///
        `""Level 3 migration", "Level 2 migration", "Level 1 migration""'

    frmttable using "$working_dir/output/descriptive/master/descriptive_reg_stacked_migrLevels_table", ///
        statmat(table) sdec(3) annotate(table_stars) asymbol(*,**,***) ///
        tex replace fragment ctitles(`ctitles') rtitles(`rtitles')
end

program stacked_reg_withNotEmpl
    use "$working_dir/derived_data/master_panel_descriptive", clear

    keep if occupation==0 | occupation==1 | occupation==2
    gen self_empl_base = occupation==1
    gen not_working_base = occupation==0 
    gen wage_worker_base = occupation==2

    egen country_followUP = group(country followUp)
    gen ihs_income = ln(income + sqrt(income^2 + 1))

    build_stacked_table, outcomes("any_migr internal_migr international_migr") additional_control(not_working_base)

    local ctitles = `""", "Any migration", "Internal migration", "International migration", "' + ///
        `""Any migration", "Internal migration", "International migration""'
    local rtitles = `""Self-employed" \ "" \ "Not working" \ "" \ "Aged 25 to 34" \ "" \ "Aged 35 to 44" \ "" \ "Aged 45 to 54" \ "" \ "' + ///
        `""Aged 55 to 65" \ "" \ "Years of education" \ "" \ "Female" \ "" \ "arcsinh(income)" \ "" \ "Wage worker mean" \ "Sample size""'

    frmttable using "$working_dir/output/descriptive/master/descriptive_reg_stacked_withNotEmpl_table", ///
        statmat(table) sdec(3) annotate(table_stars) asymbol(*,**,***) ///
        tex replace fragment ctitles(`ctitles') rtitles(`rtitles')
end

program build_separate_table
    syntax, fup(str) outcomes(str)

    cap: mat drop table table_stars

    foreach income_exog in "" "ihs_income" {
        foreach outcome in `outcomes' {
            cap: mat drop col

            qui probit `outcome'_`fup' self_empl_base i.age_group educyears female `income_exog' i.country_nbr
            local sample_size = e(N)
            
            qui margins, dydx(*) atmeans

            mat V_diag = vecdiag(r(V))
            mat coefs = r(b)

            if "`income_exog'" == "" local nbr_coefs 8
            else if "`income_exog'" == "ihs_income" local nbr_coefs 9

            foreach num of numlist 1 3/`nbr_coefs' { 
                mat col = (nullmat(col) \ coefs[1,`num'] \ sqrt(V_diag[1,`num']))
            }

            qui mean `outcome'_`fup' if wage_worker_base==1 & ///
                age_group!=. & educyears!=. & female!=.

            if "`income_exog'" == "" mat col = (col \ . \ . \ e(b) \ `sample_size')
            else if "`income_exog'" == "ihs_income" mat col = (col \ e(b) \ `sample_size')

            probit_signifstars, mat_name(col)
            mat col_stars = r(stars)
            
            mat table = (nullmat(table), col)
            mat table_stars = (nullmat(table_stars), col_stars)
        }
    }
end

program build_stacked_table
    syntax, outcomes(str) [additional_control(str)]

    cap: mat drop table table_stars

    foreach income_exog in "" "ihs_income" {
        foreach outcome in `outcomes' {
            cap: mat drop col

            qui probit `outcome' self_empl_base `additional_control' i.age_group educyears female ///
                `income_exog' i.country_followUP, cluster(person_id)
            local sample_size = e(N)
            
            qui margins, dydx(*) atmeans

            mat V_diag = vecdiag(r(V))
            mat coefs = r(b)

            if "`income_exog'" == "" local nbr_coefs 8
            else if "`income_exog'" == "ihs_income" local nbr_coefs 9

            local start_age_dummies = 3

            if "`additional_control'"!="" {
                local nbr_coefs = `nbr_coefs' + 1
                local include_add_control = 2
                local start_age_dummies = 4
            }

            foreach num of numlist 1 `include_add_control' `start_age_dummies'/`nbr_coefs' { 
                mat col = (nullmat(col) \ coefs[1,`num'] \ sqrt(V_diag[1,`num']))
            }

            qui mean `outcome' if wage_worker_base==1 & ///
                age_group!=. & educyears!=. & female!=.

            if "`income_exog'" == "" mat col = (col \ . \ . \ e(b) \ `sample_size')
            else if "`income_exog'" == "ihs_income" mat col = (col \ e(b) \ `sample_size')

            probit_signifstars, mat_name(col)
            mat col_stars = r(stars)
            
            mat table = (nullmat(table), col)
            mat table_stars = (nullmat(table_stars), col_stars)
        }
    }
end

* Execute
main
