clear all
set more off

global working_dir "C:/Users/Samuele/Dropbox (Brown)/MigrationSelfEmployment/for_publication"

program main
    first_followups
    append_second_followups
end

program first_followups
    * Follow administrative divisions in this table: 
    * https://en.wikipedia.org/wiki/List_of_administrative_divisions_by_country
    
    local usevars = "person_id female educyears age_group income " + ///
        "occupation country any_migr_1stFup internal_migr_1stFup"

    use `usevars' self_empl_1stFup wage_worker_1stFup not_working_1stFup ///
        agri_worker_1stFup province_migr_1stFup county_migr_1stFup ///
        using "$working_dir/temp/cfps_master", clear

    gen level1_migr_1stFup = .
    gen level2_migr_1stFup = .
    gen level3_migr_1stFup = .

    * Counties in China would be level 3, but makes more sense to define then as level 2 
    * if compared to other countries 
    replace level1_migr_1stFup = province_migr_1stFup if country=="China"
    replace level2_migr_1stFup = county_migr_1stFup if country=="China"

    append using "$working_dir/temp/elmps_master", ///
        keep(`usevars' self_empl_1stFup wage_worker_1stFup not_working_1stFup ///
        agri_worker_1stFup gov_migr_1stFup qism_migr_1stFup shyakha_migr_1stFup)

    replace level1_migr_1stFup = gov_migr_1stFup if country=="Egypt"
    replace level2_migr_1stFup = qism_migr_1stFup if country=="Egypt"
    replace level3_migr_1stFup = shyakha_migr_1stFup if country=="Egypt"

    * Note: cannot use same state migration since it does not further distinguish
    * between levels underneath
    append using "$working_dir/temp/ihds_master", ///
        keep(`usevars' international_migr_1stFup state_migr_1stFup ///
        self_empl_1stFup wage_worker_1stFup not_working_1stFup agri_worker_1stFup)

    replace level1_migr_1stFup = state_migr_1stFup

    append using "$working_dir/temp/ifls_master", ///
        keep(`usevars' international_migr_1stFup self_empl_1stFup wage_worker_1stFup ///
        not_working_1stFup agri_worker_1stFup province_migr_1stFup kab_migr_1stFup kec_migr_1stFup)

    * Note: for Indonesia, Kecamatan are districts, so might be level 2 (and not 3)
    replace level1_migr_1stFup = province_migr_1stFup if country=="Indonesia"
    replace level2_migr_1stFup = kab_migr_1stFup if country=="Indonesia"
    replace level3_migr_1stFup = kec_migr_1stFup if country=="Indonesia"

    append using "$working_dir/temp/mxfls_1stFup", ///
        keep(`usevars' international_migr_1stFup state_migr_1stFup ///
        municipio_migr_1stFup locality_migr_1stFup)

    replace level1_migr_1stFup = state_migr_1stFup if country=="Mexico"
    replace level2_migr_1stFup = municipio_migr_1stFup if country=="Mexico"
    replace level3_migr_1stFup = locality_migr_1stFup if country=="Mexico"

    append using "$working_dir/temp/lsms_isa_1stFup", ///
        keep(`usevars' international_migr_1stFup state_migr_1stFup lga_migr_1stFup)

    replace level1_migr_1stFup = state_migr_1stFup if country=="Nigeria"
    replace level2_migr_1stFup = lga_migr_1stFup if country=="Nigeria"

    append using "$working_dir/temp/khds_master", ///
        keep(`usevars' international_migr_1stFup self_empl_1stFup ///
        wage_worker_1stFup not_working_1stFup agri_worker_1stFup regional_migr_1stFup ///
        withinKagera_migr_1stFup village_migr_1stFup)

    replace level1_migr_1stFup = regional_migr_1stFup if country=="Tanzania"
    replace level2_migr_1stFup = withinKagera_migr_1stFup if country=="Tanzania"
    replace level3_migr_1stFup = village_migr_1stFup if country=="Tanzania"

    append using "$working_dir/temp/psid_master", ///
        keep(`usevars' international_migr_1stFup self_empl_1stFup ///
        wage_worker_1stFup not_working_1stFup)

    replace level1_migr_1stFup = internal_migr_1stFup if country=="USA"
    
    gen followUp = 1

    foreach var in any_migr internal_migr international_migr level1_migr level2_migr level3_migr {
        gen `var' = `var'_1stFup
    }
    rename (self_empl_1stFup wage_worker_1stFup not_working_1stFup agri_worker_1stFup) ///
        (self_empl_dest wage_worker_dest not_working_dest agri_worker_dest)

    save "$working_dir/derived_data/master_panel_descriptive", replace
end

program append_second_followups
    local usevars = "person_id female educyears age_group income " + ///
        "occupation country any_migr_2ndFup internal_migr_2ndFup"
    
    use `usevars' self_empl_2ndFup wage_worker_2ndFup not_working_2ndFup ///
        agri_worker_2ndFup gov_migr_2ndFup qism_migr_2ndFup shyakha_migr_2ndFup ///
        using "$working_dir/temp/elmps_master", clear

    gen level1_migr_2ndFup = .
    gen level2_migr_2ndFup = .
    gen level3_migr_2ndFup = .

    replace level1_migr_2ndFup = gov_migr_2ndFup if country=="Egypt"
    replace level2_migr_2ndFup = qism_migr_2ndFup if country=="Egypt"
    replace level3_migr_2ndFup = shyakha_migr_2ndFup if country=="Egypt"

    append using "$working_dir/temp/ifls_master", /// 
        keep(`usevars' international_migr_2ndFup self_empl_2ndFup wage_worker_2ndFup ///
        not_working_2ndFup agri_worker_2ndFup province_migr_2ndFup kab_migr_2ndFup kec_migr_2ndFup)

    replace level1_migr_2ndFup = province_migr_2ndFup if country=="Indonesia"
    replace level2_migr_2ndFup = kab_migr_2ndFup if country=="Indonesia"
    replace level3_migr_2ndFup = kec_migr_2ndFup if country=="Indonesia"

    append using "$working_dir/temp/mxfls_2ndFup", ///
        keep(`usevars' international_migr_2ndFup state_migr_2ndFup ///
        municipio_migr_2ndFup locality_migr_2ndFup)

    replace level1_migr_2ndFup = state_migr_2ndFup if country=="Mexico"
    replace level2_migr_2ndFup = municipio_migr_2ndFup if country=="Mexico"
    replace level3_migr_2ndFup = locality_migr_2ndFup if country=="Mexico"

    append using "$working_dir/temp/lsms_isa_2ndFup", ///
        keep(`usevars' international_migr_2ndFup state_migr_2ndFup lga_migr_2ndFup)

    replace level1_migr_2ndFup = state_migr_2ndFup if country=="Nigeria"
    replace level2_migr_2ndFup = lga_migr_2ndFup if country=="Nigeria"

    append using "$working_dir/temp/khds_master", ///
        keep(`usevars' international_migr_2ndFup self_empl_2ndFup wage_worker_2ndFup agri_worker_2ndFup ///
        not_working_2ndFup regional_migr_2ndFup withinKagera_migr_2ndFup village_migr_2ndFup)

    replace level1_migr_2ndFup = regional_migr_2ndFup if country=="Tanzania"
    replace level2_migr_2ndFup = withinKagera_migr_2ndFup if country=="Tanzania"
    replace level3_migr_2ndFup = village_migr_2ndFup if country=="Tanzania"

    append using "$working_dir/temp/psid_master", ///
        keep(`usevars' international_migr_2ndFup self_empl_2ndFup ///
        wage_worker_2ndFup not_working_2ndFup)

    replace level1_migr_2ndFup = internal_migr_2ndFup if country=="USA"

    gen followUp = 2

    foreach var in any_migr internal_migr international_migr level1_migr level2_migr level3_migr {
        gen `var' = `var'_2ndFup
    }
    rename (self_empl_2ndFup wage_worker_2ndFup not_working_2ndFup agri_worker_2ndFup) ///
        (self_empl_dest wage_worker_dest not_working_dest agri_worker_dest)

    * Append first follow-ups
    append using "$working_dir/derived_data/master_panel_descriptive"

    save "$working_dir/derived_data/master_panel_descriptive", replace
end

* Execute
main
